/*= Rohde&Schwarz FSH series Spectrum Analyzer Include File =================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __rsfsh_HEADER
#define __rsfsh_HEADER
#include <visa.h>
#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_PARAMETER1       (_VI_ERROR+0x3FFC0001L)
#define VI_ERROR_PARAMETER2       (_VI_ERROR+0x3FFC0002L)
#define VI_ERROR_PARAMETER3       (_VI_ERROR+0x3FFC0003L)
#define VI_ERROR_PARAMETER4       (_VI_ERROR+0x3FFC0004L)
#define VI_ERROR_PARAMETER5       (_VI_ERROR+0x3FFC0005L)
#define VI_ERROR_PARAMETER6       (_VI_ERROR+0x3FFC0006L)
#define VI_ERROR_PARAMETER7       (_VI_ERROR+0x3FFC0007L)
#define VI_ERROR_PARAMETER8       (_VI_ERROR+0x3FFC0008L)
#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)

#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                         (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)
    
/* Add instrument driver specific error codes here */
#define RSFSH_ERROR_UNKNOWN_ERROR              (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define RSFSH_ERROR_SYNTAX_ERROR               (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSFSH_ERROR_EXECUTION_ERROR            (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSFSH_ERROR_DATASET_STORAGE_FULL       (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSFSH_ERROR_NOT_ALLOWED                (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSFSH_ERROR_OUT_OF_RANGE               (VI_ERROR_INSTR_OFFSET + 0xF5L)
#define RSFSH_ERROR_INSTRUMENT_ERROR           (VI_ERROR_INSTR_OFFSET + 0xF6L)

#define RSFSH_WARNING_SMALL_BUFFER             (VI_WARNING_INSTR_OFFSET + 0xF1L)

/*****************************************************************************/
/*= Instrument specific defines =============================================*/
/*****************************************************************************/
#define RSFSH_VAL_FREQ_MODE_CW   0
#define RSFSH_VAL_FREQ_MODE_FIX  1
#define RSFSH_VAL_FREQ_MODE_SWE  2
#define RSFSH_VAL_FREQ_MODE_SCAN 3
    
#define RSFSH_VAL_TRACE_SPACE_LIN 0
#define RSFSH_VAL_TRACE_SPACE_LOG 1
#define RSFSH_VAL_TRACE_SPACE_PCT 2
#define RSFSH_VAL_TRACE_SPACE_LDB 3
    
#define RSFSH_VAL_AMPLITUDE_UNITS_DBM       0
#define RSFSH_VAL_AMPLITUDE_UNITS_DBUV      1
#define RSFSH_VAL_AMPLITUDE_UNITS_DBMV      2
#define RSFSH_VAL_AMPLITUDE_UNITS_VOLT      3
#define RSFSH_VAL_AMPLITUDE_UNITS_WATT      4
    
#define RSFSH_TRAC_MOD_WRITE 0
#define RSFSH_TRAC_MOD_VIEW  1
#define RSFSH_TRAC_MOD_AVER  2
#define RSFSH_TRAC_MOD_MAXH  3
#define RSFSH_TRAC_MOD_MINH  4
#define RSFSH_TRAC_MOD_BLANK 5
    
#define RSFSH_VAL_DETECTOR_TYPE_AUTO_PEAK  0
#define RSFSH_VAL_DETECTOR_TYPE_NEGATIVE   1
#define RSFSH_VAL_DETECTOR_TYPE_POSITIVE   2
#define RSFSH_VAL_DETECTOR_TYPE_SAMPLE     3
#define RSFSH_VAL_DETECTOR_TYPE_RMS        4
#define RSFSH_VAL_DETECTOR_TYPE_AVERAGE    5
#define RSFSH_VAL_DETECTOR_TYPE_QUASI_PEAK 6
    
#define RSFSH_VAL_NEG 0
#define RSFSH_VAL_POS 1
    
#define RSFSH_VAL_TRIGGER_SOURCE_IMM   0
#define RSFSH_VAL_TRIGGER_SOURCE_VIDEO 1
#define RSFSH_VAL_TRIGGER_SOURCE_EXT   4
    
#define RSFSH_VAL_COUPLING_RBW        0
#define RSFSH_VAL_COUPLING_VBW        1
#define RSFSH_VAL_COUPLING_SWEEP_TIME 2
    
#define RSFSH_VAL_MARKER_SEARCH_HIGHEST      0
#define RSFSH_VAL_MARKER_SEARCH_NEXT_PEAK    1
#define RSFSH_VAL_MARKER_SEARCH_MINIMUM      2
#define RSFSH_VAL_MARKER_SEARCH_NEXT_MINIMUM 3
    
#define RSFSH_MEASUREMENT_MODE_SAN 0
#define RSFSH_MEASUREMENT_MODE_NAN 1
#define RSFSH_MEASUREMENT_MODE_DTF 2
#define RSFSH_MEASUREMENT_MODE_POW 3
#define RSFSH_MEASUREMENT_MODE_BWCD 4
#define RSFSH_MEASUREMENT_MODE_BC2K 5
#define RSFSH_MEASUREMENT_MODE_BDO  6
#define RSFSH_MEASUREMENT_MODE_REC  7
#define RSFSH_MEASUREMENT_MODE_GSM  8
#define RSFSH_MEASUREMENT_MODE_TDSCDMA 9
#define RSFSH_MEASUREMENT_MODE_WCDMA   10
#define RSFSH_MEASUREMENT_MODE_LTEF    11
#define RSFSH_MEASUREMENT_MODE_LTET    12
    
    
#define RSFSH_FREQ_STEP_LINK_DIVT 0
#define RSFSH_FREQ_STEP_LINK_OFF  1
    
#define RSFSH_VAL_FREQ_INPUT_MODE_CHAN 0
#define RSFSH_VAL_FREQ_INPUT_MODE_FREQ 1
    
#define RSFSH_IMPEDANCE_PAD_RAM  0
#define RSFSH_IMPEDANCE_PAD_RAZ  1
#define RSFSH_IMPEDANCE_PAD_HZTE 2
    
#define RSFSH_RF_INPUT_MODE_ATT_LDIST 0
#define RSFSH_RF_INPUT_MODE_ATT_LNOIS 1
    
#define RSFSH_VAL_MARKER_DISPLAY_MODE_FREQ 0
#define RSFSH_VAL_MARKER_DISPLAY_MODE_CHAN 1
    
#define RSFSH_VAL_MARKER_OUTPUT_FORMAT_NORM 0
#define RSFSH_VAL_MARKER_OUTPUT_FORMAT_RPDB 1
#define RSFSH_VAL_MARKER_OUTPUT_FORMAT_RPL  2
#define RSFSH_VAL_MARKER_OUTPUT_FORMAT_RSC  3
#define RSFSH_VAL_MARKER_OUTPUT_FORMAT_IMP  4
#define RSFSH_VAL_MARKER_OUTPUT_FORMAT_ADM  5
#define RSFSH_VAL_MARKER_OUTPUT_FORMAT_NIMP 6
#define RSFSH_VAL_MARKER_OUTPUT_FORMAT_NADM 7
    
#define RSFSH_VAL_CPOW_UNIT_DBM  0
#define RSFSH_VAL_CPOW_UNIT_DBMV 1
#define RSFSH_VAL_CPOW_UNIT_DBUV 2
#define RSFSH_VAL_CPOW_UNIT_VOLT 3
#define RSFSH_VAL_CPOW_UNIT_WATT 4
#define RSFSH_VAL_CPOW_UNIT_DUVM 5
#define RSFSH_VAL_CPOW_UNIT_DUAM 6
#define RSFSH_VAL_CPOW_UNIT_V    7
#define RSFSH_VAL_CPOW_UNIT_W    8
#define RSFSH_VAL_CPOW_UNIT_V_M  9
#define RSFSH_VAL_CPOW_UNIT_W_M2 10
    
#define RSFSH_VAL_DEMOD_TYPE_AM 0
#define RSFSH_VAL_DEMOD_TYPE_FM 1
    
#define RSFSH_MAGNITUDE_SPACING_LIN 0
#define RSFSH_MAGNITUDE_SPACING_LOG 1
    
#define RSFSH_DISPLAY_REFLECTION_UNIT_RHO  0
#define RSFSH_DISPLAY_REFLECTION_UNIT_MRHO 1
    
#define RSFSH_VAL_POWER_CPOW 0
#define RSFSH_VAL_POWER_OBW  1
#define RSFSH_VAL_POWER_TDMA 2
#define RSFSH_VAL_POWER_ACP  3

#define RSFSH_MEAS_FORMAT_MAGNITUDE  0
#define RSFSH_MEAS_FORMAT_PHASE      1
#define RSFSH_MEAS_FORMAT_MPHASE     2
#define RSFSH_MEAS_FORMAT_VSWR       3
#define RSFSH_MEAS_FORMAT_REFLECTION 4
#define RSFSH_MEAS_FORMAT_SMITH      5
#define RSFSH_MEAS_FORMAT_LOSS       6
#define RSFSH_MEAS_FORMAT_GDELAY     7
#define RSFSH_MEAS_FORMAT_VVMETER    8
    
#define RSFSH_DISPLAY_COLOR_SCHEME_COL 0
#define RSFSH_DISPLAY_COLOR_SCHEME_BW  1
    
#define RSFSH_DISPLAY_DATE_FORMAT_DDMM 0
#define RSFSH_DISPLAY_DATE_FORMAT_MMDD 1
    
#define RSFSH_UNIT_LENGTH_METER 0
#define RSFSH_UNIT_LENGTH_FEET  1
    
#define RSFSH_VAL_CPOW_BW_VAL  0
#define RSFSH_VAL_CPOW_BW_UP   1
#define RSFSH_VAL_CPOW_BW_DOWN 2
    
#define RSFSH_VAL_TRACKING_GEN_TYPE_CLOSS 0
#define RSFSH_VAL_TRACKING_GEN_TYPE_MAGN  1
#define RSFSH_VAL_TRACKING_GEN_TYPE_PHAS  2
#define RSFSH_VAL_TRACKING_GEN_TYPE_REFL  3
    
#define RSFSH_TRIGGER_SLOPE_POSITIVE 0
#define RSFSH_TRIGGER_SLOPE_NEGATIVE 1
    
#define RSFSH_DISPLAY_ZOOM_FACTOR_2 0
#define RSFSH_DISPLAY_ZOOM_FACTOR_4 1
#define RSFSH_DISPLAY_ZOOM_FACTOR_8 2
    
#define RSFSH_VAL_CPOW_MODE_CLR 0
#define RSFSH_VAL_CPOW_MODE_MAX 1
    
#define RSFSH_NAN_MEAS_MODE_SCALAR     0
#define RSFSH_NAN_MEAS_MODE_VECTOR     1
#define RSFSH_NAN_MEAS_MODE_VVM        2
#define RSFSH_DTF_MEAS_MODE_DTF        3
#define RSFSH_DTF_MEAS_MODE_REFLECTION 4
#define RSFSH_DTF_MEAS_MODE_SPECTRUM   5
    
#define RSFSH_UNIT_POWER_DBM  0
#define RSFSH_UNIT_POWER_DBUV 1
#define RSFSH_UNIT_POWER_DBMV 2
#define RSFSH_UNIT_POWER_V    3
#define RSFSH_UNIT_POWER_W    4
#define RSFSH_UNIT_POWER_DUVM 5
#define RSFSH_UNIT_POWER_DUAM 6
#define RSFSH_UNIT_POWER_V_M  7
#define RSFSH_UNIT_POWER_W_M2 8
    
#define RSFSH_BNC_MODE_REF  0
#define RSFSH_BNC_MODE_TRIG 1
#define RSFSH_BNC_MODE_BIAS 2
#define RSFSH_BNC_MODE_IF3  3
#define RSFSH_BNC_MODE_IFD  4
    
#define RSFSH_VAL_FILE_NEW    0
#define RSFSH_VAL_FILE_COPY   1
#define RSFSH_VAL_FILE_RENAME 2
#define RSFSH_VAL_FILE_DELETE 3
#define RSFSH_VAL_FILE_RDIR   4
#define RSFSH_VAL_FILE_FORMAT 5
#define RSFSH_VAL_FILE_CDIR   6
#define RSFSH_VAL_FILE_CDISC  7
    
#define RSFSH_VAL_MEM_SAVE    0
#define RSFSH_VAL_MEM_RECALL  1
#define RSFSH_VAL_MEM_DELETE  2
#define RSFSH_VAL_MEM_STARTUP 3
    
#define RSFSH_NAN_MEAS_FORMAT_MAGNITUDE  0
#define RSFSH_NAN_MEAS_FORMAT_PHASE      1
#define RSFSH_NAN_MEAS_FORMAT_MPHASE     2
#define RSFSH_NAN_MEAS_FORMAT_GDELAY     3
    
#define RSFSH_POWER_PARAMETER_CPOW 0
#define RSFSH_POWER_PARAMETER_OBAN 1
    
#define RSFSH_TRACE_TRACE1 0
#define RSFSH_TRACE_TRACE2 1
    
#define RSFSH_AUTO_SCRAMBLING_SINGLE   0
#define RSFSH_AUTO_SCRAMBLING_MULTIPLE 1

#define RSFSH_VAL_3GPP_PREF_ABS               0
#define RSFSH_VAL_3GPP_PREF_CPICH             1
    
#define RSFSH_VAL_WCDP_RES_ACH  0
#define RSFSH_VAL_WCDP_RES_CPEV 1
#define RSFSH_VAL_WCDP_RES_CPP  2
#define RSFSH_VAL_WCDP_RES_FERR 3
#define RSFSH_VAL_WCDP_RES_PCEV 4
#define RSFSH_VAL_WCDP_RES_PCP  5
#define RSFSH_VAL_WCDP_RES_PSP  6
#define RSFSH_VAL_WCDP_RES_PTOT 7
#define RSFSH_VAL_WCDP_RES_SSP  8
    
#define RSFSH_VAL_C2K_PREF_PICH  0
#define RSFSH_VAL_C2K_PREF_TOT   1
    
#define RSFSH_VAL_C2K_ACT      0
#define RSFSH_VAL_C2K_FERP     1
#define RSFSH_VAL_C2K_FERR     2
#define RSFSH_VAL_C2K_MACC     3
#define RSFSH_VAL_C2K_PNF      4
#define RSFSH_VAL_C2K_PPAV     5
#define RSFSH_VAL_C2K_PTOT     6
#define RSFSH_VAL_C2K_RHO      7
#define RSFSH_VAL_C2K_TAU      8
    
#define RSFSH_VAL_EVDO_EVMP        0
#define RSFSH_VAL_EVDO_FERR        1
#define RSFSH_VAL_EVDO_PNF         2
#define RSFSH_VAL_EVDO_PAV         3
#define RSFSH_VAL_EVDO_PDAT        4
#define RSFSH_VAL_EVDO_PMAC        5
#define RSFSH_VAL_EVDO_PPIL        6
#define RSFSH_VAL_EVDO_PTOT        7
#define RSFSH_VAL_EVDO_RHOP        8
#define RSFSH_VAL_EVDO_TACT        9
#define RSFSH_VAL_EVDO_TAU        10

#define RSFSH_VAL_EVDO_PREF_PICH  0
#define RSFSH_VAL_EVDO_PREF_TOT   1
    
#define RSFSH_VAL_BC2K_RES_TYPE_SPECTRUM  0
#define RSFSH_VAL_BC2K_RES_TYPE_CDP       1
#define RSFSH_VAL_BC2K_RES_TYPE_SUMMARY   2
#define RSFSH_VAL_BC2K_RES_TYPE_CDCT      3
    
#define RSFSH_VAL_EVDOB_RES_TYPE_SPECTRUM 0
#define RSFSH_VAL_EVDOB_RES_TYPE_SUMMARY  1 
    
#define FSH3 1
#define FSH4 0
    
#define RSFSH_VAL_POWERSENSOR_UNITS_DBM       0
#define RSFSH_VAL_POWERSENSOR_UNITS_W         1
#define RSFSH_VAL_POWERSENSOR_UNITS_DB        2
#define RSFSH_VAL_POWERSENSOR_UNITS_VSWR      3
    
#define RSFSH_VAL_POWERSENSOR_PWR_DISP_AVER 0
#define RSFSH_VAL_POWERSENSOR_PWR_DISP_PENV 1
    
#define RSFSH_VAL_SWEEP_MODE_AUTO           0 
#define RSFSH_VAL_SWEEP_MODE_ESP            1
#define RSFSH_VAL_SWEEP_MODE_LIST           2

    
#define RSFSH_VAL_ACP_TXAUTO_MIN 0
#define RSFSH_VAL_ACP_TXAUTO_MAX 1
#define RSFSH_VAL_ACP_TXAUTO_LHI 2
    
#define RSFSH_VAL_ACP_LIMIT_REL 0
#define RSFSH_VAL_ACP_LIMIT_ABS 1
    
#define RSFSH_VAL_ACPOW_UNIT_DBM  0
#define RSFSH_VAL_ACPOW_UNIT_DBMV 1
#define RSFSH_VAL_ACPOW_UNIT_DBUV 2
#define RSFSH_VAL_ACPOW_UNIT_V    3
#define RSFSH_VAL_ACPOW_UNIT_W    4
    
#define RSFSH_VAL_MARKER_MODE_NORM 0    
#define RSFSH_VAL_MARKER_MODE_RPDB 1
#define RSFSH_VAL_MARKER_MODE_RPL  2
#define RSFSH_VAL_MARKER_MODE_RSC  3
#define RSFSH_VAL_MARKER_MODE_IMP  4
#define RSFSH_VAL_MARKER_MODE_ADM  5
#define RSFSH_VAL_MARKER_MODE_NIMP 6
#define RSFSH_VAL_MARKER_MODE_NADM 7

#define RSFSH_VAL_ROSC_SOUR_INT 0
#define RSFSH_VAL_ROSC_SOUR_EXT 1
	
#define RSFSH_3GPP_MEAS_CARRFREQERR  0
#define RSFSH_3GPP_MEAS_CPICHPWR     1
#define RSFSH_3GPP_MEAS_CPICHSLOTNR  2
#define RSFSH_3GPP_MEAS_CPICHSYMEVM  3
#define RSFSH_3GPP_MEAS_PCCPCHPWR    4
#define RSFSH_3GPP_MEAS_PCCPCHPWRREL 5
#define RSFSH_3GPP_MEAS_PCCPCHSYMEVM 6
#define RSFSH_3GPP_MEAS_PSCHPWR      7
#define RSFSH_3GPP_MEAS_PSCHPWRREL   8
#define RSFSH_3GPP_MEAS_SSCHPWR      9
#define RSFSH_3GPP_MEAS_SSCHPWRREL   10
#define RSFSH_3GPP_MEAS_TOTPWR       11
#define RSFSH_3GPP_MEAS_CPICHEIRAT   12
#define RSFSH_3GPP_MEAS_PCCPCHEIRAT  13
	
#define RSFHS_VAL_DIRECTION_DOWNLINK 0
#define RSFHS_VAL_DIRECTION_UPLINK   1

#define RSFSH_VAL_ISOANTENA_DIRECTION_AUTO 0
#define RSFSH_VAL_ISOANTENA_DIRECTION_X    1
#define RSFSH_VAL_ISOANTENA_DIRECTION_Y    2
#define RSFSH_VAL_ISOANTENA_DIRECTION_Z    3

#define RSFSH_VAL_CFE_UNIT_HZ  0
#define RSFSH_VAL_CFE_UNIT_PPM 1
	
#define RSFSH_VAL_SOEV_STORAGE_SDC 0
#define RSFSH_VAL_SOEV_STORAGE_USB 1
	
#define RSFSH_VAL_SOEV_SOURCE_ALLS 0
#define RSFSH_VAL_SOEV_SOURCE_DIST 1
#define RSFSH_VAL_SOEV_SOURCE_LIM  2
#define RSFSH_VAL_SOEV_SOURCE_TIM  3
	
#define RSFSH_VAL_SOEV_LIMITS_MODE_FAIL 0
#define RSFSH_VAL_SOEV_LIMITS_MODE_STAR 1
#define RSFSH_VAL_SOEV_LIMITS_MODE_STOP 2
	
#define RSFSH_VAL_CALIBRATION_F2PC 0
#define RSFSH_VAL_CALIBRATION_F2PN 1
#define RSFSH_VAL_CALIBRATION_F2PH 2
#define RSFSH_VAL_CALIBRATION_S11C 3
#define RSFSH_VAL_CALIBRATION_S11  4
#define RSFSH_VAL_CALIBRATION_S11N 5
#define RSFSH_VAL_CALIBRATION_S12C 6
#define RSFSH_VAL_CALIBRATION_S12N 7
#define RSFSH_VAL_CALIBRATION_S21C 8
#define RSFSH_VAL_CALIBRATION_S21N 9
#define RSFSH_VAL_CALIBRATION_S22C 10
#define RSFSH_VAL_CALIBRATION_S22  11
#define RSFSH_VAL_CALIBRATION_S22N 12

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC rsfsh_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViSession* instrumentHandle);
ViStatus _VI_FUNC rsfsh_readSpectrum (ViSession instrumentHandle,
                                      ViReal64 centerFrequency,
                                      ViReal64 frequencySpan,
                                      ViReal64 frequencyOffset,
                                      ViReal64 referenceLevel, ViInt32 unit,
                                      ViReal64 referenceLevelOffset,
                                      ViReal64 _VI_FAR traceData[],
                                      ViInt32* samplesReturned, ViInt32 trace);
ViStatus _VI_FUNC rsfsh_setMeasMode (ViSession instrumentHandle,
                                     ViInt32 measurementMode);
ViStatus _VI_FUNC rsfsh_configureDisplayLine (ViSession instrumentHandle,
                                              ViBoolean state, ViReal64 position);
ViStatus _VI_FUNC rsfsh_getMeasMode (ViSession instrumentHandle,
                                     ViInt32* measurementMode);
ViStatus _VI_FUNC rsfsh_setSerialBaudRate (ViSession instrumentHandle,
                                           ViInt32 baudRate);
ViStatus _VI_FUNC rsfsh_getSerialBaudRate (ViSession instrumentHandle,
                                           ViInt32* baudRate);
ViStatus _VI_FUNC rsfsh_getExternalReferenceStatus (ViSession instrumentHandle,
                                                    ViInt32* externalReferenceStatus);
ViStatus _VI_FUNC rsfsh_setRemoteLocalMode (ViSession instrumentHandle,
                                            ViBoolean mode);
ViStatus _VI_FUNC rsfsh_setExternalInputConnector (ViSession instrumentHandle,
                                                   ViBoolean externalInputConnector);
ViStatus _VI_FUNC rsfsh_getExternalInputConnector (ViSession instrumentHandle,
                                                   ViBoolean* externalInputConnector);
ViStatus _VI_FUNC rsfsh_setAccessory (ViSession instrumentHandle,
                                      ViInt32 accessory);
ViStatus _VI_FUNC rsfsh_getAccessory (ViSession instrumentHandle,
                                      ViInt32* accessory);
ViStatus _VI_FUNC rsfsh_setDisplay (ViSession instrumentHandle, ViBoolean display);
ViStatus _VI_FUNC rsfsh_getDisplay (ViSession instrumentHandle, ViBoolean* display);
ViStatus _VI_FUNC rsfsh_setDisplayLinePosition (ViSession instrumentHandle,
                                                ViReal64 position);
ViStatus _VI_FUNC rsfsh_getDisplayLinePosition (ViSession instrumentHandle,
                                                ViReal64* position);
ViStatus _VI_FUNC rsfsh_setDisplayLineState (ViSession instrumentHandle,
                                             ViBoolean state);
ViStatus _VI_FUNC rsfsh_getDisplayLineState (ViSession instrumentHandle,
                                             ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setDisplayLogRange (ViSession instrumentHandle,
                                            ViReal64 range);
ViStatus _VI_FUNC rsfsh_getDisplayLogRange (ViSession instrumentHandle,
                                            ViReal64* range);
ViStatus _VI_FUNC rsfsh_displayScreenshot (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_configureFrequency (ViSession instrumentHandle,
                                            ViReal64 centerFrequency,
                                            ViReal64 frequencySpan,
                                            ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsfsh_configureFrequencyStartStop (ViSession instrumentHandle,
                                                     ViReal64 startFrequency,
                                                     ViReal64 stopFrequency);
ViStatus _VI_FUNC rsfsh_configureFrequencySpanFull (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_setCenterFrequency (ViSession instrumentHandle,
                                            ViReal64 centerFrequency);
ViStatus _VI_FUNC rsfsh_getCenterFrequency (ViSession instrumentHandle,
                                            ViReal64* centerFrequency);
ViStatus _VI_FUNC rsfsh_setFrequencySpan (ViSession instrumentHandle,
                                          ViReal64 frequencySpan);
ViStatus _VI_FUNC rsfsh_getFrequencySpan (ViSession instrumentHandle,
                                          ViReal64* frequencySpan);
ViStatus _VI_FUNC rsfsh_setFrequencyOffset (ViSession instrumentHandle,
                                            ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsfsh_getFrequencyOffset (ViSession instrumentHandle,
                                            ViReal64* frequencyOffset);
ViStatus _VI_FUNC rsfsh_setStartFrequency (ViSession instrumentHandle,
                                           ViReal64 startFrequency);
ViStatus _VI_FUNC rsfsh_getStartFrequency (ViSession instrumentHandle,
                                           ViReal64* startFrequency);
ViStatus _VI_FUNC rsfsh_setStopFrequency (ViSession instrumentHandle,
                                          ViReal64 stopFrequency);
ViStatus _VI_FUNC rsfsh_getStopFrequency (ViSession instrumentHandle,
                                          ViReal64* stopFrequency);
ViStatus _VI_FUNC rsfsh_setAutoSpanMode (ViSession instrumentHandle,
                                         ViBoolean spanMode);
ViStatus _VI_FUNC rsfsh_getAutoSpanMode (ViSession instrumentHandle,
                                         ViBoolean* spanMode);
ViStatus _VI_FUNC rsfsh_setStepSizeFrequency (ViSession instrumentHandle,
                                              ViReal64 stepSize);
ViStatus _VI_FUNC rsfsh_getStepSizeFrequency (ViSession instrumentHandle,
                                              ViReal64* stepSize);
ViStatus _VI_FUNC rsfsh_setStepLink (ViSession instrumentHandle, ViInt32 stepLink);
ViStatus _VI_FUNC rsfsh_getStepLink (ViSession instrumentHandle, ViInt32* stepLink);
ViStatus _VI_FUNC rsfsh_setFrequencyInputMode (ViSession instrumentHandle,
                                               ViInt32 inputMode);
ViStatus _VI_FUNC rsfsh_getFrequencyInputMode (ViSession instrumentHandle,
                                               ViInt32* inputMode);
ViStatus _VI_FUNC rsfsh_setFrequencyMode (ViSession instrumentHandle,
                                          ViInt32 frequencyMode);
ViStatus _VI_FUNC rsfsh_getFrequencyMode (ViSession instrumentHandle,
                                          ViInt32* frequencyMode);
ViStatus _VI_FUNC rsfsh_setChannelNumber (ViSession instrumentHandle,
                                          ViInt32 numberOfChannel);
ViStatus _VI_FUNC rsfsh_getChannelNumber (ViSession instrumentHandle,
                                          ViInt32* numberOfChannel);
ViStatus _VI_FUNC rsfsh_configureAmplitude (ViSession instrumentHandle,
                                            ViReal64 referenceLevel, ViInt32 unit,
                                            ViReal64 referenceLevelOffset);
ViStatus _VI_FUNC rsfsh_setReferenceLevel (ViSession instrumentHandle,
                                           ViReal64 referenceLevel);
ViStatus _VI_FUNC rsfsh_getReferenceLevel (ViSession instrumentHandle,
                                           ViReal64* referenceLevel);
ViStatus _VI_FUNC rsfsh_setReferenceLevelOffset (ViSession instrumentHandle,
                                                 ViReal64 referenceLevelOffset);
ViStatus _VI_FUNC rsfsh_getReferenceLevelOffset (ViSession instrumentHandle,
                                                 ViReal64* referenceLevelOffset);
ViStatus _VI_FUNC rsfsh_setVerticalScale (ViSession instrumentHandle, ViInt32 trace,
                                          ViInt32 verticalScale);
ViStatus _VI_FUNC rsfsh_getVerticalScale (ViSession instrumentHandle, ViInt32 trace,
                                          ViInt32* verticalScale);
ViStatus _VI_FUNC rsfsh_setLevelRange (ViSession instrumentHandle, ViInt32 range);
ViStatus _VI_FUNC rsfsh_getLevelRange (ViSession instrumentHandle, ViInt32* range);
ViStatus _VI_FUNC rsfsh_setDynamicRange (ViSession instrumentHandle,
                                         ViBoolean range);
ViStatus _VI_FUNC rsfsh_getDynamicRange (ViSession instrumentHandle,
                                         ViBoolean* range);
ViStatus _VI_FUNC rsfsh_setLevelUnits (ViSession instrumentHandle, ViInt32 unit);
ViStatus _VI_FUNC rsfsh_getLevelUnits (ViSession instrumentHandle, ViInt32* unit);
ViStatus _VI_FUNC rsfsh_setRFInputImpedance (ViSession instrumentHandle,
                                             ViInt32 RFInputImpedance);
ViStatus _VI_FUNC rsfsh_getRFInputImpedance (ViSession instrumentHandle,
                                             ViInt32* RFInputImpedance);
ViStatus _VI_FUNC rsfsh_setPreamplifierState (ViSession instrumentHandle,
                                              ViBoolean preamplifier);
ViStatus _VI_FUNC rsfsh_getPreamplifierState (ViSession instrumentHandle,
                                              ViBoolean* preamplifier);
ViStatus _VI_FUNC rsfsh_setAmplitudeUnits (ViSession instrumentHandle,
                                           ViInt32 amplitudeUnits);
ViStatus _VI_FUNC rsfsh_getAmplitudeUnits (ViSession instrumentHandle,
                                           ViInt32* amplitudeUnits);
ViStatus _VI_FUNC rsfsh_SelectTransducerFactor (ViSession instrumentHandle,
                                                ViInt32 transducer,
                                                ViString transducerFactor);
ViStatus _VI_FUNC rsfsh_getSelectedTransducerFactor (ViSession instrumentHandle,
                                                     ViInt32 transducer,
                                                     ViChar _VI_FAR transducerFactor[]);
ViStatus _VI_FUNC rsfsh_setTransducerFactorState (ViSession instrumentHandle,
                                                  ViInt32 transducer,
                                                  ViBoolean state);
ViStatus _VI_FUNC rsfsh_getTransducerFactorState (ViSession instrumentHandle,
                                                  ViInt32 transducer,
                                                  ViBoolean* state);
ViStatus _VI_FUNC rsfsh_getTransducerFactorUnit (ViSession instrumentHandle,
                                                 ViInt32 transducer,
                                                 ViChar _VI_FAR unit[]);
ViStatus _VI_FUNC rsfsh_configureBandwidth (ViSession instrumentHandle,
                                            ViInt32 resolutionBandwidth,
                                            ViInt32 videoBandwidth);
ViStatus _VI_FUNC rsfsh_setResolutionBandwidth (ViSession instrumentHandle,
                                                ViInt32 resolutionBandwidth);
ViStatus _VI_FUNC rsfsh_getResolutionBandwidth (ViSession instrumentHandle,
                                                ViInt32* resolutionBandwidth);
ViStatus _VI_FUNC rsfsh_setAutoResolutionBandwidth (ViSession instrumentHandle,
                                                    ViBoolean autoResolutionBandwidth);
ViStatus _VI_FUNC rsfsh_getAutoResolutionBandwidth (ViSession instrumentHandle,
                                                    ViBoolean* autoResolutionBandwidth);
ViStatus _VI_FUNC rsfsh_setVideoBandwidth (ViSession instrumentHandle,
                                           ViInt32 videoBandwidth);
ViStatus _VI_FUNC rsfsh_getVideoBandwidth (ViSession instrumentHandle,
                                           ViInt32* videoBandwidth);
ViStatus _VI_FUNC rsfsh_setAutoVideoBandwidth (ViSession instrumentHandle,
                                               ViBoolean autoVideoBandwidth);
ViStatus _VI_FUNC rsfsh_getAutoVideoBandwidth (ViSession instrumentHandle,
                                               ViBoolean* autoVideoBandwidth);
ViStatus _VI_FUNC rsfsh_setCISPRBandwidth (ViSession instrumentHandle,
                                           ViInt32 CISPRBandwidth);
ViStatus _VI_FUNC rsfsh_getCISPRBandwidth (ViSession instrumentHandle,
                                           ViInt32* CISPRBandwidth);
ViStatus _VI_FUNC rsfsh_setAutoCISPRBandwidth (ViSession instrumentHandle,
                                               ViBoolean autoCISPRBandwidth);
ViStatus _VI_FUNC rsfsh_getAutoCISPRBandwidth (ViSession instrumentHandle,
                                               ViBoolean* autoCISPRBandwidth);
ViStatus _VI_FUNC rsfsh_configureSweep (ViSession instrumentHandle,
                                        ViInt32 sweepMode, ViReal64 sweepTime,
                                        ViInt32 triggerSource);
ViStatus _VI_FUNC rsfsh_configureTrigger (ViSession instrumentHandle,
                                          ViInt32 videoLevel,
                                          ViInt32 triggerPolarity,
                                          ViInt32 triggerSource);
ViStatus _VI_FUNC rsfsh_configureSweepCouplingAuto (ViSession instrumentHandle,
                                                    ViInt32 sweepCoupling);
ViStatus _VI_FUNC rsfsh_configureSweepCoupling (ViSession instrumentHandle,
                                                ViInt32 sweepCoupling,
                                                ViReal64 couplingValue);
ViStatus _VI_FUNC rsfsh_configureAcquisition (ViSession instrumentHandle,
                                              ViBoolean sweepModeContinuous,
                                              ViInt32 numberOfSweeps);
ViStatus _VI_FUNC rsfsh_setSweepTime (ViSession instrumentHandle,
                                      ViReal64 sweepTime);
ViStatus _VI_FUNC rsfsh_getSweepTime (ViSession instrumentHandle,
                                      ViReal64* sweepTime);
ViStatus _VI_FUNC rsfsh_setAutoSweepTime (ViSession instrumentHandle,
                                          ViBoolean autoSweepTime);
ViStatus _VI_FUNC rsfsh_getAutoSweepTime (ViSession instrumentHandle,
                                          ViBoolean* autoSweepTime);
ViStatus _VI_FUNC rsfsh_setSweepMode (ViSession instrumentHandle,
                                      ViInt32 sweepMode);
ViStatus _VI_FUNC rsfsh_getSweepMode (ViSession instrumentHandle,
                                      ViInt32* sweepMode);
ViStatus _VI_FUNC rsfsh_setNumberOfSweeps (ViSession instrumentHandle,
                                           ViInt32 numberOfSweeps);
ViStatus _VI_FUNC rsfsh_getNumberOfSweeps (ViSession instrumentHandle,
                                           ViInt32* numberOfSweeps);
ViStatus _VI_FUNC rsfsh_setSweepModeContinuous (ViSession instrumentHandle,
                                                ViBoolean sweepModeContinuous);
ViStatus _VI_FUNC rsfsh_getSweepModeContinuous (ViSession instrumentHandle,
                                                ViBoolean* sweepModeContinuous);
ViStatus _VI_FUNC rsfsh_setTriggerSource (ViSession instrumentHandle,
                                          ViInt32 triggerSource);
ViStatus _VI_FUNC rsfsh_getTriggerSource (ViSession instrumentHandle,
                                          ViInt32* triggerSource);
ViStatus _VI_FUNC rsfsh_setTriggerLevel (ViSession instrumentHandle,
                                         ViInt32 triggerLevel);
ViStatus _VI_FUNC rsfsh_getTriggerLevel (ViSession instrumentHandle,
                                         ViInt32* triggerLevel);
ViStatus _VI_FUNC rsfsh_setTriggerDelay (ViSession instrumentHandle,
                                         ViReal64 triggerDelay);
ViStatus _VI_FUNC rsfsh_getTriggerDelay (ViSession instrumentHandle,
                                         ViReal64* triggerDelay);
ViStatus _VI_FUNC rsfsh_setTriggerPolarity (ViSession instrumentHandle,
                                            ViInt32 triggerPolarity);
ViStatus _VI_FUNC rsfsh_getTriggerPolarity (ViSession instrumentHandle,
                                            ViInt32* triggerPolarity);
ViStatus _VI_FUNC rsfsh_setTriggerVideoLevel (ViSession instrumentHandle,
                                              ViInt32 videoLevel);
ViStatus _VI_FUNC rsfsh_getTriggerVideoLevel (ViSession instrumentHandle,
                                              ViInt32* videoLevel);
ViStatus _VI_FUNC rsfsh_sendTrigger (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_sendTriggerWopc (ViSession instrumentHandle,
                                         ViInt32 timeout);
ViStatus _VI_FUNC rsfsh_configureTrace (ViSession instrumentHandle,
                                        ViInt32 traceMode, ViInt32 traceDetector);
ViStatus _VI_FUNC rsfsh_configureTraceDetector (ViSession instrumentHandle,
                                                ViInt32 trace,
                                                ViBoolean detectorTypeAuto,
                                                ViInt32 detectorType);
ViStatus _VI_FUNC rsfsh_configureTraceMath (ViSession instrumentHandle,
                                            ViInt32 trace, ViBoolean state,
                                            ViString expression);
ViStatus _VI_FUNC rsfsh_setTraceToMemory (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_setTraceMode (ViSession instrumentHandle,
                                      ViInt32 traceMode);
ViStatus _VI_FUNC rsfsh_getTraceMode (ViSession instrumentHandle,
                                      ViInt32* traceMode);
ViStatus _VI_FUNC rsfsh_SetTraceStyle (ViSession instrumentHandle,
                                       ViInt32 traceStyle);
ViStatus _VI_FUNC rsfsh_GetTraceStyle (ViSession instrumentHandle,
                                       ViInt32* traceStyle);
ViStatus _VI_FUNC rsfsh_setTraceState (ViSession instrumentHandle, ViInt32 trace,
                                       ViBoolean state);
ViStatus _VI_FUNC rsfsh_getTraceState (ViSession instrumentHandle, ViInt32 trace,
                                       ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setMemoryTraceState (ViSession instrumentHandle,
                                             ViInt32 trace, ViBoolean state);
ViStatus _VI_FUNC rsfsh_getMemoryTraceState (ViSession instrumentHandle,
                                             ViInt32 trace, ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setTraceDetector (ViSession instrumentHandle,
                                          ViInt32 traceDetector);
ViStatus _VI_FUNC rsfsh_getTraceDetector (ViSession instrumentHandle,
                                          ViInt32* traceDetector);
ViStatus _VI_FUNC rsfsh_setTraceDetectorAuto (ViSession instrumentHandle,
                                              ViInt32 trace,
                                              ViBoolean detectorTypeAuto);
ViStatus _VI_FUNC rsfsh_getTraceDetectorAuto (ViSession instrumentHandle,
                                              ViInt32 trace,
                                              ViBoolean* detectorTypeAuto);
ViStatus _VI_FUNC rsfsh_setTraceDetectorType (ViSession instrumentHandle,
                                              ViInt32 detectorType);
ViStatus _VI_FUNC rsfsh_getTraceDetectorType (ViSession instrumentHandle,
                                              ViInt32* detectorType);
ViStatus _VI_FUNC rsfsh_setTraceAverage (ViSession instrumentHandle,
                                         ViInt32 numberOfTraces);
ViStatus _VI_FUNC rsfsh_getTraceAverage (ViSession instrumentHandle,
                                         ViInt32* numberOfTraces);
ViStatus _VI_FUNC rsfsh_readTraceData (ViSession instrumentHandle, ViInt32 trace,
                                       ViReal64 _VI_FAR traceData[],
                                       ViInt32* samplesReturned);
ViStatus _VI_FUNC rsfsh_readTraceDataASCII (ViSession instrumentHandle,
                                            ViReal64 _VI_FAR traceData[],
                                            ViInt32* samplesReturned);
ViStatus _VI_FUNC rsfsh_readComplexTraceData (ViSession instrumentHandle,
                                              ViReal64 _VI_FAR magnitude[],
                                              ViReal64 _VI_FAR phase[],
                                              ViInt32* samplesReturned);
ViStatus _VI_FUNC rsfsh_readComplexTraceDataASCII (ViSession instrumentHandle,
                                                   ViReal64 _VI_FAR magnitude[],
                                                   ViReal64 _VI_FAR phase[],
                                                   ViInt32* samplesReturned);
ViStatus _VI_FUNC rsfsh_readTraceDataFromSavedDataSet (ViSession instrumentHandle,
                                                       ViString dataSet,
                                                       ViReal64 _VI_FAR traceData[],
                                                       ViInt32* samplesReturned);
ViStatus _VI_FUNC rsfsh_readTraceDataFromSavedDataSetASCII
             (ViSession instrumentHandle, ViString dataSet,
              ViReal64 _VI_FAR traceData[], ViInt32* samplesReturned);
ViStatus _VI_FUNC rsfsh_readComplexCorrectedTraceData (ViSession instrumentHandle,
                                                       ViReal64 _VI_FAR magnitude[],
                                                       ViReal64 _VI_FAR phase[],
                                                       ViInt32* samplesReturned);
ViStatus _VI_FUNC rsfsh_readComplexCorrectedTraceDataASCII
             (ViSession instrumentHandle, ViReal64 _VI_FAR magnitude[],
              ViReal64 _VI_FAR phase[], ViInt32* samplesReturned);
ViStatus _VI_FUNC rsfsh_ReadReceiverTraceData (ViSession instrumentHandle,
                                               ViUInt32 maximumTime_ms,
                                               ViInt32 arrayLength,
                                               ViReal64 _VI_FAR amplitude[],
                                               ViInt32* actualPoints);
ViStatus _VI_FUNC rsfsh_setTraceMathMode (ViSession instrumentHandle,
                                          ViInt32 mathMode);
ViStatus _VI_FUNC rsfsh_getTraceMathMode (ViSession instrumentHandle,
                                          ViInt32* mathMode);
ViStatus _VI_FUNC rsfsh_setTraceMathState (ViSession instrumentHandle,
                                           ViInt32 trace, ViBoolean state);
ViStatus _VI_FUNC rsfsh_getTraceMathState (ViSession instrumentHandle,
                                           ViInt32 trace, ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setTraceMathExpression (ViSession instrumentHandle,
                                                ViInt32 trace, ViString expression);
ViStatus _VI_FUNC rsfsh_getTraceMathExpression (ViSession instrumentHandle,
                                                ViInt32 trace,
                                                ViChar _VI_FAR expression[]);
ViStatus _VI_FUNC rsfsh_copyTraceToMemory (ViSession instrumentHandle,
                                           ViInt32 trace);
ViStatus _VI_FUNC rsfsh_configureInputImpedance (ViSession instrumentHandle,
                                                 ViInt32 inputImpedance);
ViStatus _VI_FUNC rsfsh_configureAttenuation (ViSession instrumentHandle,
                                              ViBoolean attenuationAuto,
                                              ViReal64 attenuation,
                                              ViInt32 attenuationMode);
ViStatus _VI_FUNC rsfsh_setInputImpedance (ViSession instrumentHandle,
                                           ViInt32 inputImpedance);
ViStatus _VI_FUNC rsfsh_getInputImpedance (ViSession instrumentHandle,
                                           ViInt32* inputImpedance);
ViStatus _VI_FUNC rsfsh_setInputImpedancePad (ViSession instrumentHandle,
                                              ViInt32 pad);
ViStatus _VI_FUNC rsfsh_getInputImpedancePad (ViSession instrumentHandle,
                                              ViInt32* pad);
ViStatus _VI_FUNC rsfsh_setAttenuationMode (ViSession instrumentHandle,
                                            ViInt32 attenuationMode);
ViStatus _VI_FUNC rsfsh_getAttenuationMode (ViSession instrumentHandle,
                                            ViInt32* attenuationMode);
ViStatus _VI_FUNC rsfsh_setAttenuationAuto (ViSession instrumentHandle,
                                            ViBoolean attenuationAuto);
ViStatus _VI_FUNC rsfsh_getAttenuationAuto (ViSession instrumentHandle,
                                            ViBoolean* attenuationAuto);
ViStatus _VI_FUNC rsfsh_setAttenuation (ViSession instrumentHandle,
                                        ViReal64 attenuation);
ViStatus _VI_FUNC rsfsh_getAttenuation (ViSession instrumentHandle,
                                        ViReal64* attenuation);
ViStatus _VI_FUNC rsfsh_configureMarker (ViSession instrumentHandle, ViInt32 marker,
                                         ViBoolean markerState,
                                         ViReal64 markerPosition,
                                         ViInt32 deltamarker,
                                         ViBoolean deltamarkerState,
                                         ViReal64 deltamarkerPosition);
ViStatus _VI_FUNC rsfsh_configureMarkerSearchLimit (ViSession instrumentHandle,
                                                    ViInt32 marker, ViBoolean state,
                                                    ViReal64 limitLeft,
                                                    ViReal64 limitRight);
ViStatus _VI_FUNC rsfsh_configureMarkerZoom (ViSession instrumentHandle,
                                             ViBoolean zoom, ViInt32 zoomFactor,
                                             ViReal64 x, ViReal64 y);
ViStatus _VI_FUNC rsfsh_configureMarkerDemodulation (ViSession instrumentHandle,
                                                     ViInt32 marker,
                                                     ViBoolean state,
                                                     ViReal64 holdTime,
                                                     ViInt32 type);
ViStatus _VI_FUNC rsfsh_setActiveMarker (ViSession instrumentHandle,
                                         ViInt32 marker);
ViStatus _VI_FUNC rsfsh_getActiveMarker (ViSession instrumentHandle,
                                         ViInt32* marker);
ViStatus _VI_FUNC rsfsh_setMarkerState (ViSession instrumentHandle, ViInt32 marker,
                                        ViBoolean markerState);
ViStatus _VI_FUNC rsfsh_getMarkerState (ViSession instrumentHandle, ViInt32 marker,
                                        ViBoolean* markerState);
ViStatus _VI_FUNC rsfsh_setMarkerPosition (ViSession instrumentHandle,
                                           ViInt32 marker, ViReal64 markerPosition);
ViStatus _VI_FUNC rsfsh_getMarkerPosition (ViSession instrumentHandle,
                                           ViInt32 marker, ViReal64* x);
ViStatus _VI_FUNC rsfsh_getMarkerValue (ViSession instrumentHandle,
                                        ViReal64* markerPosition,
                                        ViReal64* markerLevel);
ViStatus _VI_FUNC rsfsh_disableAllMarkers (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_setActiveDeltaMarker (ViSession instrumentHandle,
                                              ViInt32 deltamarker);
ViStatus _VI_FUNC rsfsh_getActiveDeltaMarker (ViSession instrumentHandle,
                                              ViInt32* deltamarker);
ViStatus _VI_FUNC rsfsh_setDeltamarkerState (ViSession instrumentHandle,
                                             ViInt32 deltamarker,
                                             ViBoolean deltamarkerState);
ViStatus _VI_FUNC rsfsh_getDeltamarkerState (ViSession instrumentHandle,
                                             ViInt32 deltamarker,
                                             ViBoolean* deltamarkerState);
ViStatus _VI_FUNC rsfsh_setDeltamarkerPosition (ViSession instrumentHandle,
                                                ViInt32 deltamarker,
                                                ViReal64 deltamarkerPosition);
ViStatus _VI_FUNC rsfsh_getDeltamarkerPosition (ViSession instrumentHandle,
                                                ViInt32 deltamarker,
                                                ViReal64* deltamarkerPosition);
ViStatus _VI_FUNC rsfsh_setDeltamarkerFrequencyorTime (ViSession instrumentHandle,
                                                       ViInt32 deltamarker,
                                                       ViReal64 frequencyOrTime);
ViStatus _VI_FUNC rsfsh_getDeltamarkerFrequencyorTime (ViSession instrumentHandle,
                                                       ViInt32 deltamarker,
                                                       ViReal64* frequencyOrTime);
ViStatus _VI_FUNC rsfsh_getDeltamarkerValue (ViSession instrumentHandle,
                                             ViInt32 deltamarker,
                                             ViReal64* deltamarkerPosition,
                                             ViReal64* deltamarkerLevel);
ViStatus _VI_FUNC rsfsh_disableAllDeltaMarkers (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_deltaMarkerSearch (ViSession instrumentHandle,
                                           ViInt32 deltaMarker,
                                           ViInt32 markerSearch);
ViStatus _VI_FUNC rsfsh_markerSearch (ViSession instrumentHandle, ViInt32 marker,
                                      ViInt32 markerSearch);
ViStatus _VI_FUNC rsfsh_setMarkerTo (ViSession instrumentHandle, ViInt32 markerTo);
ViStatus _VI_FUNC rsfsh_setMarkerMode (ViSession instrumentHandle,
                                       ViInt32 markerMode);
ViStatus _VI_FUNC rsfsh_getMarkerMode (ViSession instrumentHandle,
                                       ViInt32* markerMode);
ViStatus _VI_FUNC rsfsh_setMarkerDemodulationMode (ViSession instrumentHandle,
                                                   ViInt32 demodulation);
ViStatus _VI_FUNC rsfsh_getMarkerDemodulationMode (ViSession instrumentHandle,
                                                   ViInt32* demodulation);
ViStatus _VI_FUNC rsfsh_setMarkerDemodulationTime (ViSession instrumentHandle,
                                                   ViReal64 demodulationTime);
ViStatus _VI_FUNC rsfsh_setMarkerDemodulationAFOutputVolume
             (ViSession instrumentHandle, ViInt32 demodulationVolume);
ViStatus _VI_FUNC rsfsh_setMarkerImpedanceReference (ViSession instrumentHandle,
                                                     ViInt32 markerImpedanceReference);
ViStatus _VI_FUNC rsfsh_getMarkerImpedanceReference (ViSession instrumentHandle,
                                                     ViInt32* markerImpedanceReference);
ViStatus _VI_FUNC rsfsh_setMarkerMeasurementMode (ViSession instrumentHandle,
                                                  ViInt32 markerMeasMode);
ViStatus _VI_FUNC rsfsh_getMarkerMeasurementMode (ViSession instrumentHandle,
                                                  ViInt32* markerMeasMode);
ViStatus _VI_FUNC rsfsh_setMarkerFrequencyCounter (ViSession instrumentHandle,
                                                   ViInt32 marker,
                                                   ViBoolean frequencyCounter);
ViStatus _VI_FUNC rsfsh_getMarkerFrequencyCounter (ViSession instrumentHandle,
                                                   ViInt32 marker,
                                                   ViBoolean* frequencyCounter);
ViStatus _VI_FUNC rsfsh_getMarkerFrequencyCounterResult (ViSession instrumentHandle,
                                                         ViInt32 marker,
                                                         ViReal64* result);
ViStatus _VI_FUNC rsfsh_setMarkerDisplayMode (ViSession instrumentHandle,
                                              ViInt32 marker, ViInt32 displayMode);
ViStatus _VI_FUNC rsfsh_getMarkerDisplayMode (ViSession instrumentHandle,
                                              ViInt32 marker, ViInt32* displayMode);
ViStatus _VI_FUNC rsfsh_setMarkerCenterFrequency (ViSession instrumentHandle,
                                                  ViInt32 marker);
ViStatus _VI_FUNC rsfsh_setMarkerReferenceFrequency (ViSession instrumentHandle,
                                                     ViInt32 marker);
ViStatus _VI_FUNC rsfsh_setMarkerOutputFormat (ViSession instrumentHandle,
                                               ViInt32 marker,
                                               ViInt32 outputFormat);
ViStatus _VI_FUNC rsfsh_getMarkerOutputFormat (ViSession instrumentHandle,
                                               ViInt32 marker,
                                               ViInt32* outputFormat);
ViStatus _VI_FUNC rsfsh_getMarkerY (ViSession instrumentHandle, ViInt32 marker,
                                    ViReal64* y);
ViStatus _VI_FUNC rsfsh_setMarkerReferenceLeveltoMarker (ViSession instrumentHandle,
                                                         ViInt32 marker);
ViStatus _VI_FUNC rsfsh_getMarkerList (ViSession instrumentHandle,
                                       ViInt32* markerCount,
                                       ViInt32 _VI_FAR markerNumberArray[],
                                       ViReal64 _VI_FAR markerPosition[],
                                       ViReal64 _VI_FAR markerValue[]);
ViStatus _VI_FUNC rsfsh_getDeltaMarkerList (ViSession instrumentHandle,
                                            ViInt32* deltamarkerCount,
                                            ViInt32 _VI_FAR deltaMarkerNumberArray[],
                                            ViReal64 _VI_FAR deltamarkerPosition[],
                                            ViReal64 _VI_FAR deltamarkerValue[]);
ViStatus _VI_FUNC rsfsh_setMarkerZoomState (ViSession instrumentHandle,
                                            ViBoolean zoom);
ViStatus _VI_FUNC rsfsh_getMarkerZoomState (ViSession instrumentHandle,
                                            ViBoolean* zoom);
ViStatus _VI_FUNC rsfsh_setMarkerZoomFactor (ViSession instrumentHandle,
                                             ViInt32 zoomFactor);
ViStatus _VI_FUNC rsfsh_getMarkerZoomFactor (ViSession instrumentHandle,
                                             ViInt32* zoomFactor);
ViStatus _VI_FUNC rsfsh_setMarkerZoomX (ViSession instrumentHandle, ViReal64 x);
ViStatus _VI_FUNC rsfsh_getMarkerZoomX (ViSession instrumentHandle, ViReal64* x);
ViStatus _VI_FUNC rsfsh_setMarkerZoomY (ViSession instrumentHandle, ViReal64 y);
ViStatus _VI_FUNC rsfsh_getMarkerZoomY (ViSession instrumentHandle, ViReal64* y);
ViStatus _VI_FUNC rsfsh_setMarkerSearchLimitState (ViSession instrumentHandle,
                                                   ViInt32 marker, ViBoolean state);
ViStatus _VI_FUNC rsfsh_getMarkerSearchLimitState (ViSession instrumentHandle,
                                                   ViInt32 marker,
                                                   ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setMarkerSearchLimitLeft (ViSession instrumentHandle,
                                                  ViReal64 leftLimit);
ViStatus _VI_FUNC rsfsh_getMarkerSearchLimitLeft (ViSession instrumentHandle,
                                                  ViReal64* leftLimit);
ViStatus _VI_FUNC rsfsh_setMarkerSearchLimitRight (ViSession instrumentHandle,
                                                   ViReal64 rightLimit);
ViStatus _VI_FUNC rsfsh_getMarkerSearchLimitRight (ViSession instrumentHandle,
                                                   ViReal64* rightLimit);
ViStatus _VI_FUNC rsfsh_setMarkerDemodulationState (ViSession instrumentHandle,
                                                    ViInt32 marker,
                                                    ViBoolean state);
ViStatus _VI_FUNC rsfsh_getMarkerDemodulationState (ViSession instrumentHandle,
                                                    ViInt32 marker,
                                                    ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setMarkerDemodulationHoldTime (ViSession instrumentHandle,
                                                       ViReal64 holdTime);
ViStatus _VI_FUNC rsfsh_getMarkerDemodulationHoldTime (ViSession instrumentHandle,
                                                       ViReal64* holdTime);
ViStatus _VI_FUNC rsfsh_setMarkerDemodulationType (ViSession instrumentHandle,
                                                   ViInt32 type);
ViStatus _VI_FUNC rsfsh_getMarkerDemodulationType (ViSession instrumentHandle,
                                                   ViInt32* type);
ViStatus _VI_FUNC rsfsh_setMarkerNoiseState (ViSession instrumentHandle,
                                             ViInt32 marker, ViBoolean state);
ViStatus _VI_FUNC rsfsh_getMarkerNoiseState (ViSession instrumentHandle,
                                             ViInt32 marker, ViBoolean* state);
ViStatus _VI_FUNC rsfsh_getMarkerNoiseResult (ViSession instrumentHandle,
                                              ViInt32 marker, ViReal64* result);
ViStatus _VI_FUNC rsfsh_setndBDownMarkerState (ViSession instrumentHandle,
                                               ViInt32 marker, ViBoolean down);
ViStatus _VI_FUNC rsfsh_getndBDownMarkerState (ViSession instrumentHandle,
                                               ViInt32 marker, ViBoolean* down);
ViStatus _VI_FUNC rsfsh_setndBDownMarkerDistance (ViSession instrumentHandle,
                                                  ViInt32 marker,
                                                  ViReal64 distance);
ViStatus _VI_FUNC rsfsh_getndBDownMarkerDistance (ViSession instrumentHandle,
                                                  ViInt32 marker,
                                                  ViReal64* distance);
ViStatus _VI_FUNC rsfsh_getndBDownMarkerFrequency (ViSession instrumentHandle,
                                                   ViInt32 marker,
                                                   ViInt32* frequency1,
                                                   ViInt32* frequency2);
ViStatus _VI_FUNC rsfsh_getndBDownMarkerBandwidth (ViSession instrumentHandle,
                                                   ViInt32 marker,
                                                   ViReal64* bandwidth);
ViStatus _VI_FUNC rsfsh_initiateMeasurement (ViSession instrumentHandle,
                                             ViUInt32 timeout);
ViStatus _VI_FUNC rsfsh_abortMeasurement (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_configureTransducer (ViSession instrumentHandle,
                                             ViString transducerName,
                                             ViString transducerDBName);
ViStatus _VI_FUNC rsfsh_configureDirectionTransducer (ViSession instrumentHandle,
                                                      ViString transducerXName,
                                                      ViString transducerYName,
                                                      ViString transducerZName);
ViStatus _VI_FUNC rsfsh_configureLimitLines (ViSession instrumentHandle,
                                             ViInt32 limit, ViString lowerLimitLine,
                                             ViString upperLimitLine,
                                             ViBoolean state, ViBoolean audioBeep);
ViStatus _VI_FUNC rsfsh_configurendBDownValue (ViSession instrumentHandle,
                                               ViReal64 nDBDown);
ViStatus _VI_FUNC rsfsh_queryndBDownResult (ViSession instrumentHandle,
                                            ViReal64* nDBDown);
ViStatus _VI_FUNC rsfsh_setMeasurementMode (ViSession instrumentHandle,
                                            ViInt32 measurementMode);
ViStatus _VI_FUNC rsfsh_getMeasurementMode (ViSession instrumentHandle,
                                            ViInt32* measurementMode);
ViStatus _VI_FUNC rsfsh_setTransducer (ViSession instrumentHandle,
                                       ViString transducerName);
ViStatus _VI_FUNC rsfsh_getTransducer (ViSession instrumentHandle,
                                       ViChar _VI_FAR transducerName[]);
ViStatus _VI_FUNC rsfsh_setXTransducer (ViSession instrumentHandle,
                                        ViString transducerName);
ViStatus _VI_FUNC rsfsh_getXTransducer (ViSession instrumentHandle,
                                        ViChar _VI_FAR transducerName[]);
ViStatus _VI_FUNC rsfsh_setYTransducer (ViSession instrumentHandle,
                                        ViString transducerName);
ViStatus _VI_FUNC rsfsh_getYTransducer (ViSession instrumentHandle,
                                        ViChar _VI_FAR transducerName[]);
ViStatus _VI_FUNC rsfsh_setZTransducer (ViSession instrumentHandle,
                                        ViString transducerName);
ViStatus _VI_FUNC rsfsh_getZTransducer (ViSession instrumentHandle,
                                        ViChar _VI_FAR transducerName[]);
ViStatus _VI_FUNC rsfsh_setTransducerdB (ViSession instrumentHandle,
                                         ViString transducerName);
ViStatus _VI_FUNC rsfsh_getTransducerdB (ViSession instrumentHandle,
                                         ViChar _VI_FAR transducerName[]);
ViStatus _VI_FUNC rsfsh_setLowerLimitLine (ViSession instrumentHandle,
                                           ViString lowerLimitLine);
ViStatus _VI_FUNC rsfsh_getLowerLimitLine (ViSession instrumentHandle,
                                           ViChar _VI_FAR lowerLimitLine[]);
ViStatus _VI_FUNC rsfsh_setUpperLimitLine (ViSession instrumentHandle,
                                           ViString upperLimitLine);
ViStatus _VI_FUNC rsfsh_getUpperLimitLine (ViSession instrumentHandle,
                                           ViChar _VI_FAR upperLimitLine[]);
ViStatus _VI_FUNC rsfsh_getLimitCheckStatus (ViSession instrumentHandle,
                                             ViInt32* checkStatus);
ViStatus _VI_FUNC rsfsh_setLowerThresholdLine (ViSession instrumentHandle,
                                               ViReal64 lowerThresholdLine);
ViStatus _VI_FUNC rsfsh_getLowerThresholdLine (ViSession instrumentHandle,
                                               ViReal64* lowerThresholdLine);
ViStatus _VI_FUNC rsfsh_setUpperThresholdLine (ViSession instrumentHandle,
                                               ViReal64 upperThresholdLine);
ViStatus _VI_FUNC rsfsh_getUpperThresholdLine (ViSession instrumentHandle,
                                               ViReal64* upperThresholdLine);
ViStatus _VI_FUNC rsfsh_getThresholdLineCheckStatus (ViSession instrumentHandle,
                                                     ViInt32* checkStatus);
ViStatus _VI_FUNC rsfsh_setThresholdOff (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_getndBDownValue (ViSession instrumentHandle,
                                         ViReal64* nDBDown);
ViStatus _VI_FUNC rsfsh_getNumberOfMeasurementPoints (ViSession instrumentHandle,
                                                      ViInt32* numberOfMeasurementPoints);
ViStatus _VI_FUNC rsfsh_defineLimitLine (ViSession instrumentHandle, ViString name,
                                         ViString description, ViInt32 xUnit,
                                         ViInt32 xScale, ViInt32 yUnit,
                                         ViInt32 arraySize,
                                         ViReal64 _VI_FAR xValues[],
                                         ViReal64 _VI_FAR yValues[]);
ViStatus _VI_FUNC rsfsh_deleteLimitLine (ViSession instrumentHandle, ViInt32 limit,
                                         ViString name);
ViStatus _VI_FUNC rsfsh_limitLinesList (ViSession instrumentHandle,
                                        ViInt32 bufferSize, ViChar _VI_FAR list[]);
ViStatus _VI_FUNC rsfsh_setLimitLineAudioBeep (ViSession instrumentHandle,
                                               ViBoolean audioBeep);
ViStatus _VI_FUNC rsfsh_getLimitLineAudioBeep (ViSession instrumentHandle,
                                               ViBoolean* audioBeep);
ViStatus _VI_FUNC rsfsh_getLimitLineDescription (ViSession instrumentHandle,
                                                 ViInt32 limit,
                                                 ViChar _VI_FAR description[]);
ViStatus _VI_FUNC rsfsh_getLimitLineCheckResult (ViSession instrumentHandle,
                                                 ViInt32 limit,
                                                 ViInt32* limitCheck);
ViStatus _VI_FUNC rsfsh_selectLimitLineUpper (ViSession instrumentHandle,
                                              ViString limitLineName);
ViStatus _VI_FUNC rsfsh_selectLimitLineLower (ViSession instrumentHandle,
                                              ViString limitLineName);
ViStatus _VI_FUNC rsfsh_setLimitLineState (ViSession instrumentHandle,
                                           ViInt32 limit, ViBoolean state);
ViStatus _VI_FUNC rsfsh_getLimitLineState (ViSession instrumentHandle,
                                           ViInt32 limit, ViBoolean* state);
ViStatus _VI_FUNC rsfsh_getLimitLineUnitX (ViSession instrumentHandle,
                                           ViInt32 limit, ViChar _VI_FAR unitX[]);
ViStatus _VI_FUNC rsfsh_getLimitLineUnitY (ViSession instrumentHandle,
                                           ViInt32 limit, ViChar _VI_FAR unitY[]);
ViStatus _VI_FUNC rsfsh_configureTrackingGeneratorReferenceLevel
             (ViSession instrumentHandle, ViInt32 type, ViReal64 referenceLevel,
              ViInt32 referencePosition);
ViStatus _VI_FUNC rsfsh_configureTrackingGeneratorYScale (ViSession instrumentHandle,
                                                          ViInt32 type,
                                                          ViReal64 yScale);
ViStatus _VI_FUNC rsfsh_configureTrackingGeneratorCalibration
             (ViSession instrumentHandle, ViInt32 transducer, ViBoolean state,
              ViString transducerFactor);
ViStatus _VI_FUNC rsfsh_setTrackingGeneratorMode (ViSession instrumentHandle,
                                                  ViInt32 trackingGeneratorMode);
ViStatus _VI_FUNC rsfsh_getTrackingGeneratorMode (ViSession instrumentHandle,
                                                  ViInt32* trackingGeneratorMode);
ViStatus _VI_FUNC rsfsh_setTrackingGeneratorOffsetLength (ViSession instrumentHandle,
                                                          ViReal64 length);
ViStatus _VI_FUNC rsfsh_getTrackingGeneratorOffsetLength (ViSession instrumentHandle,
                                                          ViReal64* length);
ViStatus _VI_FUNC rsfsh_getTransmCalibState (ViSession instrumentHandle,
                                             ViInt32* transmissionCalibrated);
ViStatus _VI_FUNC rsfsh_getTransmVectorCalibState (ViSession instrumentHandle,
                                                   ViInt32* transmissionVectorCalibrated);
ViStatus _VI_FUNC rsfsh_getReflectCalibState (ViSession instrumentHandle,
                                              ViInt32* reflectionCalibrated);
ViStatus _VI_FUNC rsfsh_getReflectVectorCalibState (ViSession instrumentHandle,
                                                    ViInt32* reflectionVectorCalibrated);
ViStatus _VI_FUNC rsfsh_setTrackingGeneratorLevelAttenuation
             (ViSession instrumentHandle, ViInt32 levelAttenuation);
ViStatus _VI_FUNC rsfsh_getTrackingGeneratorLevelAttenuation
             (ViSession instrumentHandle, ViInt32* levelAttenuation);
ViStatus _VI_FUNC rsfsh_setTrackingGeneratorLevel (ViSession instrumentHandle,
                                                   ViReal64 trackingGeneratorLevel);
ViStatus _VI_FUNC rsfsh_getTrackingGeneratorLevel (ViSession instrumentHandle,
                                                   ViReal64* trackingGeneratorLevel);
ViStatus _VI_FUNC rsfsh_setTrackingGeneratorOutputLevel (ViSession instrumentHandle,
                                                         ViReal64 outputLevel);
ViStatus _VI_FUNC rsfsh_getTrackingGeneratorOutputLevel (ViSession instrumentHandle,
                                                         ViReal64* outputLevel);
ViStatus _VI_FUNC rsfsh_getMeasuredCableLoss (ViSession instrumentHandle,
                                              ViReal64* cableLoss);
ViStatus _VI_FUNC rsfsh_getElectricalCableLength (ViSession instrumentHandle,
                                                  ViReal64* electricalCableLength);
ViStatus _VI_FUNC rsfsh_setElectricalCableState (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rsfsh_getElectricalCableState (ViSession instrumentHandle,
                                                 ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setElectricalCableTimeState (ViSession instrumentHandle,
                                                     ViBoolean state);
ViStatus _VI_FUNC rsfsh_getElectricalCableTimeState (ViSession instrumentHandle,
                                                     ViBoolean* state);
ViStatus _VI_FUNC rsfsh_getElectricalCableTimeLength (ViSession instrumentHandle,
                                                      ViReal64* electricalCableTime);
ViStatus _VI_FUNC rsfsh_setVSWRYScale (ViSession instrumentHandle, ViReal64 yScale);
ViStatus _VI_FUNC rsfsh_getVSWRYScale (ViSession instrumentHandle,
                                       ViReal64* yScale);
ViStatus _VI_FUNC rsfsh_setVSWRYScaleMin (ViSession instrumentHandle,
                                          ViReal64 yScaleMinimum);
ViStatus _VI_FUNC rsfsh_getVSWRYScaleMin (ViSession instrumentHandle,
                                          ViReal64* yScaleMinimum);
ViStatus _VI_FUNC rsfsh_setVSWRYScaleMax (ViSession instrumentHandle,
                                          ViReal64 yScaleMaximum);
ViStatus _VI_FUNC rsfsh_getVSWRYScaleMax (ViSession instrumentHandle,
                                          ViReal64* yScaleMaximum);
ViStatus _VI_FUNC rsfsh_getVSWRFail (ViSession instrumentHandle,
                                     ViChar _VI_FAR fail[]);
ViStatus _VI_FUNC rsfsh_setSmithChartReferenceImpedance (ViSession instrumentHandle,
                                                         ViReal64 referenceImpedance);
ViStatus _VI_FUNC rsfsh_getSmithChartReferenceImpedance (ViSession instrumentHandle,
                                                         ViReal64* referenceImpedance);
ViStatus _VI_FUNC rsfsh_setCableLossReferenceLevel (ViSession instrumentHandle,
                                                    ViReal64 referenceLevel);
ViStatus _VI_FUNC rsfsh_getCableLossReferenceLevel (ViSession instrumentHandle,
                                                    ViReal64* referenceLevel);
ViStatus _VI_FUNC rsfsh_setCableLossReferencePosition (ViSession instrumentHandle,
                                                       ViInt32 referencePosition);
ViStatus _VI_FUNC rsfsh_getCableLossReferencePosition (ViSession instrumentHandle,
                                                       ViInt32* referencePosition);
ViStatus _VI_FUNC rsfsh_setCableLossYScale (ViSession instrumentHandle,
                                            ViReal64 yScale);
ViStatus _VI_FUNC rsfsh_getCableLossYScale (ViSession instrumentHandle,
                                            ViReal64* yScale);
ViStatus _VI_FUNC rsfsh_setMagnitudeReferenceLevel (ViSession instrumentHandle,
                                                    ViReal64 referenceLevel);
ViStatus _VI_FUNC rsfsh_getMagnitudeReferenceLevel (ViSession instrumentHandle,
                                                    ViReal64* referenceLevel);
ViStatus _VI_FUNC rsfsh_setMagnitudeReferencePosition (ViSession instrumentHandle,
                                                       ViInt32 referencePosition);
ViStatus _VI_FUNC rsfsh_getMagnitudeReferencePosition (ViSession instrumentHandle,
                                                       ViInt32* referencePosition);
ViStatus _VI_FUNC rsfsh_setMagnitudeYScale (ViSession instrumentHandle,
                                            ViReal64 yScale);
ViStatus _VI_FUNC rsfsh_getMagnitudeYScale (ViSession instrumentHandle,
                                            ViReal64* yScale);
ViStatus _VI_FUNC rsfsh_setMagnitudeSpacing (ViSession instrumentHandle,
                                             ViInt32 spacing);
ViStatus _VI_FUNC rsfsh_getMagnitudeSpacing (ViSession instrumentHandle,
                                             ViInt32* spacing);
ViStatus _VI_FUNC rsfsh_setPhaseReferenceLevel (ViSession instrumentHandle,
                                                ViReal64 referenceLevel);
ViStatus _VI_FUNC rsfsh_getPhaseReferenceLevel (ViSession instrumentHandle,
                                                ViReal64* referenceLevel);
ViStatus _VI_FUNC rsfsh_setPhaseReferencePosition (ViSession instrumentHandle,
                                                   ViInt32 referencePosition);
ViStatus _VI_FUNC rsfsh_getPhaseReferencePosition (ViSession instrumentHandle,
                                                   ViInt32* referencePosition);
ViStatus _VI_FUNC rsfsh_setPhaseYScale (ViSession instrumentHandle,
                                        ViUInt32 yScale);
ViStatus _VI_FUNC rsfsh_getPhaseYScale (ViSession instrumentHandle,
                                        ViUInt32* yScale);
ViStatus _VI_FUNC rsfsh_setPhaseUnwrap (ViSession instrumentHandle,
                                        ViBoolean phaseUnwrap);
ViStatus _VI_FUNC rsfsh_getPhaseUnwrap (ViSession instrumentHandle,
                                        ViBoolean* phaseUnwrap);
ViStatus _VI_FUNC rsfsh_setReflectionCoefficientYScale (ViSession instrumentHandle,
                                                        ViInt32 yScale);
ViStatus _VI_FUNC rsfsh_getReflectionCoefficientYScale (ViSession instrumentHandle,
                                                        ViInt32* yScale);
ViStatus _VI_FUNC rsfsh_setReflectionCoefficientUnit (ViSession instrumentHandle,
                                                      ViInt32 unit);
ViStatus _VI_FUNC rsfsh_getReflectionCoefficientUnit (ViSession instrumentHandle,
                                                      ViInt32* unit);
ViStatus _VI_FUNC rsfsh_setTrackingGeneratorReferenceValue
             (ViSession instrumentHandle, ViInt32 referenceValue);
ViStatus _VI_FUNC rsfsh_getTrackingGeneratorReferenceValue
             (ViSession instrumentHandle, ViInt32* referenceValue);
ViStatus _VI_FUNC rsfsh_adjustYScale (ViSession instrumentHandle, ViInt32 trace);
ViStatus _VI_FUNC rsfsh_getIsotropicAntennaState (ViSession instrumentHandle,
                                                  ViInt32 transducer,
                                                  ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setIsotropicAntenna (ViSession instrumentHandle,
                                             ViBoolean antenna);
ViStatus _VI_FUNC rsfsh_getIsotropicAntenna (ViSession instrumentHandle,
                                             ViBoolean* antenna);
ViStatus _VI_FUNC rsfsh_setAntennaDirection (ViSession instrumentHandle,
                                             ViInt32 direction);
ViStatus _VI_FUNC rsfsh_getAntennaDirection (ViSession instrumentHandle,
                                             ViInt32* direction);
ViStatus _VI_FUNC rsfsh_trackingGeneratorScalarTransmissionCalibration
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_trackingGeneratorInitiateCalibration
             (ViSession instrumentHandle, ViInt32 trackingGeneratorCalibration);
ViStatus _VI_FUNC rsfsh_trackingGeneratorNextPhaseCalibration
             (ViSession instrumentHandle, ViInt32 trackingGeneratorCalibration);
ViStatus _VI_FUNC rsfsh_setTrackingGeneratorCalibrationTransducerState
             (ViSession instrumentHandle, ViInt32 transducer, ViBoolean state);
ViStatus _VI_FUNC rsfsh_getTrackingGeneratorCalibrationTransducerState
             (ViSession instrumentHandle, ViInt32 transducer, ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setTrackingGeneratorCalibrationTransducerSelect
             (ViSession instrumentHandle, ViInt32 transducer,
              ViString transducerFactor);
ViStatus _VI_FUNC rsfsh_getTrackingGeneratorCalibrationTransducerSelect
             (ViSession instrumentHandle, ViInt32 transducer,
              ViChar _VI_FAR transducerFactor[]);
ViStatus _VI_FUNC rsfsh_getTrackingGeneratorCalibrationTransducerUnit
             (ViSession instrumentHandle, ViInt32 transducer,
              ViChar _VI_FAR unit[]);
ViStatus _VI_FUNC rsfsh_getPowerLevel (ViSession instrumentHandle,
                                       ViReal64* powerLevel);
ViStatus _VI_FUNC rsfsh_getReflection (ViSession instrumentHandle,
                                       ViReal64* reflection);
ViStatus _VI_FUNC rsfsh_powerSensorZeroing (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_powerToReference (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_setMeasurementTime (ViSession instrumentHandle,
                                            ViInt32 measurementTime);
ViStatus _VI_FUNC rsfsh_getMeasurementTime (ViSession instrumentHandle,
                                            ViInt32* measurementTime);
ViStatus _VI_FUNC rsfsh_setReflectionUnit (ViSession instrumentHandle,
                                           ViBoolean reflectionUnit);
ViStatus _VI_FUNC rsfsh_getReflectionUnit (ViSession instrumentHandle,
                                           ViBoolean* reflectionUnit);
ViStatus _VI_FUNC rsfsh_setPowerSensorStandard (ViSession instrumentHandle,
                                                ViInt32 channelPowerStandard);
ViStatus _VI_FUNC rsfsh_getPowerSensorStandard (ViSession instrumentHandle,
                                                ViInt32* channelPowerStandard);
ViStatus _VI_FUNC rsfsh_setPowerSensorFrequency (ViSession instrumentHandle,
                                                 ViReal64 frequency);
ViStatus _VI_FUNC rsfsh_getPowerSensorFrequency (ViSession instrumentHandle,
                                                 ViReal64* frequency);
ViStatus _VI_FUNC rsfsh_setPowerSensorRelativeReferenceLevel
             (ViSession instrumentHandle, ViReal64 level);
ViStatus _VI_FUNC rsfsh_getPowerSensorRelativeReferenceLevel
             (ViSession instrumentHandle, ViReal64* level);
ViStatus _VI_FUNC rsfsh_setPowerSensorRelative (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_setPowerSensorReferenceLevelOffset
             (ViSession instrumentHandle, ViReal64 offset);
ViStatus _VI_FUNC rsfsh_getPowerSensorReferenceLevelOffset
             (ViSession instrumentHandle, ViReal64* offset);
ViStatus _VI_FUNC rsfsh_setPowerSensorUnits (ViSession instrumentHandle,
                                             ViInt32 unit, ViInt32 units);
ViStatus _VI_FUNC rsfsh_getPowerSensorUnits (ViSession instrumentHandle,
                                             ViInt32 unit, ViInt32* units);
ViStatus _VI_FUNC rsfsh_getPowerSensorVideoBandwidth (ViSession instrumentHandle,
                                                      ViReal64* videoBandwidth);
ViStatus _VI_FUNC rsfsh_setPowerSensorMeasurementTime (ViSession instrumentHandle,
                                                       ViInt32 measurementTime);
ViStatus _VI_FUNC rsfsh_getPowerSensorMeasurementTime (ViSession instrumentHandle,
                                                       ViInt32* measurementTime);
ViStatus _VI_FUNC rsfsh_setPowerSensorZeroing (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_setPowerSensorPowerDisplay (ViSession instrumentHandle,
                                                    ViInt32 powerDisplay);
ViStatus _VI_FUNC rsfsh_getPowerSensorPowerDisplay (ViSession instrumentHandle,
                                                    ViInt32* powerDisplay);
ViStatus _VI_FUNC rsfsh_getPowerSensorMeasurementsResults
             (ViSession instrumentHandle, ViInt32 unit, ViReal64* results);
ViStatus _VI_FUNC rsfsh_setPowerSensorUseStandard (ViSession instrumentHandle,
                                                   ViBoolean state);
ViStatus _VI_FUNC rsfsh_getPowerSensorUseStandard (ViSession instrumentHandle,
                                                   ViBoolean* state);
ViStatus _VI_FUNC rsfsh_selectChannelTable (ViSession instrumentHandle,
                                            ViString channelTable);
ViStatus _VI_FUNC rsfsh_setChannelTableLinkDirection (ViSession instrumentHandle,
                                                      ViInt32 linkDirection);
ViStatus _VI_FUNC rsfsh_getChannelTableLinkDirection (ViSession instrumentHandle,
                                                      ViInt32* linkDirection);
ViStatus _VI_FUNC rsfsh_setChannelTableULDLSignal (ViSession instrumentHandle,
                                                   ViInt32 signal,
                                                   ViString channelTable);
ViStatus _VI_FUNC rsfsh_getChannelTableULDLSignal (ViSession instrumentHandle,
                                                   ViInt32 signal,
                                                   ViUInt32 arraySize,
                                                   ViChar _VI_FAR channelTable[]);
ViStatus _VI_FUNC rsfsh_configureOccupiedBandwidth (ViSession instrumentHandle,
                                                    ViInt32 marker,
                                                    ViInt32 occupiedBandwidthStandard,
                                                    ViReal64 occupiedChannelBandwidth);
ViStatus _VI_FUNC rsfsh_getOccupiedBandwidth (ViSession instrumentHandle,
                                              ViReal64* occupiedBandwidth);
ViStatus _VI_FUNC rsfsh_setOccupiedBandwidthStandard (ViSession instrumentHandle,
                                                      ViInt32 occupiedBandwidthStandard);
ViStatus _VI_FUNC rsfsh_getOccupiedBandwidthStandard (ViSession instrumentHandle,
                                                      ViInt32* occupiedBandwidthStandard);
ViStatus _VI_FUNC rsfsh_setOccupiedBandwidthCustomizedStandard
             (ViSession instrumentHandle, ViString occupiedBandwidthStandard);
ViStatus _VI_FUNC rsfsh_getOccupiedBandwidthCustomizedStandard
             (ViSession instrumentHandle,
              ViString *occupiedBandwidthStandard[]);
ViStatus _VI_FUNC rsfsh_setOccupiedBandwidthChBW (ViSession instrumentHandle,
                                                  ViInt32 marker,
                                                  ViReal64 occupiedChannelBandwidth);
ViStatus _VI_FUNC rsfsh_getOccupiedBandwidthChBW (ViSession instrumentHandle,
                                                  ViInt32 marker,
                                                  ViReal64* occupiedChannelBandwidth);
ViStatus _VI_FUNC rsfsh_setOccupiedBandwidthChannelBandwidthPercentage
             (ViSession instrumentHandle, ViInt32 marker, ViInt32 percentage);
ViStatus _VI_FUNC rsfsh_getOccupiedBandwidthChannelBandwidthPercentage
             (ViSession instrumentHandle, ViInt32 marker, ViInt32* percentage);
ViStatus _VI_FUNC rsfsh_occupiedBandwidthLevelAdjust (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_configureTDMAPower (ViSession instrumentHandle,
                                            ViInt32 marker,
                                            ViInt32 TDMAPowerStandard,
                                            ViReal64 measurementTime);
ViStatus _VI_FUNC rsfsh_getTDMAPower (ViSession instrumentHandle,
                                      ViReal64* TDMAPower);
ViStatus _VI_FUNC rsfsh_setTDMAPowerStandard (ViSession instrumentHandle,
                                              ViInt32 TDMAPowerStandard);
ViStatus _VI_FUNC rsfsh_getTDMAPowerStandard (ViSession instrumentHandle,
                                              ViInt32* TDMAPowerStandard);
ViStatus _VI_FUNC rsfsh_setTDMAPowerCustomizedStandard (ViSession instrumentHandle,
                                                        ViString TDMAStandard);
ViStatus _VI_FUNC rsfsh_getTDMAPowerCustomizedStandard (ViSession instrumentHandle,
                                                        ViString *TDMAStandard);
ViStatus _VI_FUNC rsfsh_setTDMAPowerMeasurementTime (ViSession instrumentHandle,
                                                     ViInt32 marker,
                                                     ViReal64 measurementTime);
ViStatus _VI_FUNC rsfsh_getTDMAPowerMeasurementTime (ViSession instrumentHandle,
                                                     ViInt32 marker,
                                                     ViReal64* measurementTime);
ViStatus _VI_FUNC rsfsh_TDMAPowerLevelAdjust (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_configureReceiver (ViSession instrument_Handle,
                                           ViReal64 frequency,
                                           ViReal64 referenceLevel,
                                           ViInt32 resolutionBandwidth,
                                           ViInt32 traceDetector,
                                           ViReal64 measurementTime,
                                           ViInt32 channelMode, ViInt32 scanMode);
ViStatus _VI_FUNC rsfsh_setReceiverFrequency (ViStatus instrumentHandle,
                                              ViReal64 frequency);
ViStatus _VI_FUNC rsfsh_getReceiverFrequency (ViSession instrumentHandle,
                                              ViReal64* frequency);
ViStatus _VI_FUNC rsfsh_setReceiverChannelMode (ViSession instrumentHandle,
                                                ViInt32 channelMode);
ViStatus _VI_FUNC rsfsh_getReceiverChannelMode (ViSession instrumentHandle,
                                                ViInt32* channelMode);
ViStatus _VI_FUNC rsfsh_setReceiverChannelNumber (ViSession instrumentHandle,
                                                  ViInt32 channelNumber);
ViStatus _VI_FUNC rsfsh_getReceiverChannelNumber (ViSession instrumentHandle,
                                                  ViInt32* channelNumber);
ViStatus _VI_FUNC rsfsh_setReceiverChannelTable (ViSession instrumentHandle,
                                                 ViString channelTable);
ViStatus _VI_FUNC rsfsh_getReceiverChannelTable (ViSession instrumentHandle,
                                                 ViChar _VI_FAR channelTable[]);
ViStatus _VI_FUNC rsfsh_setReceiverCoupledToReferenceChannelState
             (ViSession instrumentHandle, ViBoolean coupledToReferenceChannel);
ViStatus _VI_FUNC rsfsh_getReceiverCoupledToReferenceChannelState
             (ViSession instrumentHandle, ViBoolean* coupledToReferenceChannel);
ViStatus _VI_FUNC rsfsh_setReceiverCoupledToReferenceChannel
             (ViSession instrumentHandle, ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsfsh_getReceiverCoupledToReferenceChannel
             (ViSession instrumentHandle, ViReal64* frequencyOffset);
ViStatus _VI_FUNC rsfsh_getReceiverSignalLevel (ViSession instrumentHandle,
                                                ViReal64* signalLevel);
ViStatus _VI_FUNC rsfsh_setReceiverMeasurementTime (ViSession instrumentHandle,
                                                    ViReal64 measurementTime);
ViStatus _VI_FUNC rsfsh_getReceiverMeasurementTime (ViSession instrumentHandle,
                                                    ViReal64* measurementTime);
ViStatus _VI_FUNC rsfsh_setReceiverScanMode (ViSession instrumentHandle,
                                             ViInt32 scanMode);
ViStatus _VI_FUNC rsfsh_getReceiverScanMode (ViSession instrumentHandle,
                                             ViInt32* scanMode);
ViStatus _VI_FUNC rsfsh_setReceiverFreqScanStart (ViSession instrumentHandle,
                                                  ViReal64 scanStartFrequency);
ViStatus _VI_FUNC rsfsh_getReceiverFreqScanStart (ViSession instrumentHandle,
                                                  ViReal64* scanStartFrequency);
ViStatus _VI_FUNC rsfsh_setReceiverFreqScanStop (ViSession instrumentHandle,
                                                 ViReal64 scanStopFrequency);
ViStatus _VI_FUNC rsfsh_getReceiverFreqScanStop (ViSession instrumentHandle,
                                                 ViReal64* scanStopFrequency);
ViStatus _VI_FUNC rsfsh_setReceiverFreqScanStep (ViSession instrumentHandle,
                                                 ViReal64 scanStepFrequency);
ViStatus _VI_FUNC rsfsh_getReceiverFreqScanStep (ViSession instrumentHandle,
                                                 ViReal64* scanStepFrequency);
ViStatus _VI_FUNC rsfsh_setReceiverChannelScanStart (ViSession instrumentHandle,
                                                     ViReal64 channelScanStartFrequency);
ViStatus _VI_FUNC rsfsh_getReceiverChannelScanStart (ViSession instrumentHandle,
                                                     ViReal64* channelScanStartFrequency);
ViStatus _VI_FUNC rsfsh_setReceiverChannelScanStop (ViSession instrumentHandle,
                                                    ViReal64 channelScanStopFrequency);
ViStatus _VI_FUNC rsfsh_getReceiverChannelScanStop (ViSession instrumentHandle,
                                                    ViReal64* channelScanStopFrequency);
ViStatus _VI_FUNC rsfsh_configureCarrierNoise (ViSession instrumentHandle,
                                               ViReal64 channelBandwidth,
                                               ViInt32 measurementMode,
                                               ViReal64 centerFrequency,
                                               ViBoolean norm,
                                               ViBoolean cNNoiseMeasurementActive,
                                               ViInt32 unit);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseChannelBandwidth (ViSession instrumentHandle,
                                                         ViReal64 channelBandwidth);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseChannelBandwidth (ViSession instrumentHandle,
                                                         ViReal64* channelBandwidth);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseCustomizedStandard
             (ViSession instrumentHandle, ViString customizedStandard);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseManualRefPowerActive
             (ViSession instrumentHandle, ViBoolean manualRefPowerActive);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseManualRefPowerActive
             (ViSession instrumentHandle, ViBoolean* manualRefPowerActive);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseMeasurementMode (ViSession instrumentHandle,
                                                        ViInt32 measurementMode);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseMeasurementMode (ViSession instrumentHandle,
                                                        ViInt32* measurementMode);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseMode (ViSession instrumentHandle,
                                             ViBoolean cNNoiseMeasurementActive);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseMode (ViSession instrumentHandle,
                                             ViBoolean* cNNoiseMeasurementActive);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseNoiseCorrection (ViSession instrumentHandle,
                                                        ViBoolean cNNoiseCorrection);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseNoiseCorrection (ViSession instrumentHandle,
                                                        ViBoolean* cNNoiseCorrection);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseNorm (ViSession instrumentHandle,
                                             ViBoolean norm);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseNorm (ViSession instrumentHandle,
                                             ViBoolean* norm);
ViStatus _VI_FUNC rsfsh_setCarrierNoisePilotFrequency (ViSession instrumentHandle,
                                                       ViReal64 pilotFrequency);
ViStatus _VI_FUNC rsfsh_getCarrierNoisePilotFrequency (ViSession instrumentHandle,
                                                       ViReal64* pilotFrequency);
ViStatus _VI_FUNC rsfsh_setCarrierNoisePowerDisplay (ViSession instrumentHandle,
                                                     ViBoolean powerDisplay);
ViStatus _VI_FUNC rsfsh_getCarrierNoisePowerDisplay (ViSession instrumentHandle,
                                                     ViBoolean* powerDisplay);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseRatioChannelBandwidth
             (ViSession instrumentHandle, ViReal64 ratioChannelBandwidth);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseRatioChannelBandwidth
             (ViSession instrumentHandle, ViReal64* ratioChannelBandwidth);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseReferenceMeasurementMode
             (ViSession instrumentHandle, ViInt32 referenceMeasurementMode);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseReferenceMeasurementMode
             (ViSession instrumentHandle, ViInt32* referenceMeasurementMode);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseRefPower (ViSession instrumentHandle,
                                                 ViReal64 refPower);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseRefPower (ViSession instrumentHandle,
                                                 ViReal64* refPower);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseUnit (ViSession instrumentHandle,
                                             ViInt32 unit);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseUnit (ViSession instrumentHandle,
                                             ViInt32* unit);
ViStatus _VI_FUNC rsfsh_setCarrierNoiseVisionFrequency (ViSession instrumentHandle,
                                                        ViReal64 visionFrequency);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseVisionFrequency (ViSession instrumentHandle,
                                                        ViReal64* visionFrequency);
ViStatus _VI_FUNC rsfsh_getCarrierNoiseMeasurementValue (ViSession instrumentHandle,
                                                         ViReal64* measurementValue);
ViStatus _VI_FUNC rsfsh_LevelAdjustment (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_configureGroupDelay (ViSession instrumentHandle,
                                             ViInt32 apertureSteps,
                                             ViInt32 referenceLevel,
                                             ViInt32 referencePosition,
                                             ViReal64 yScale);
ViStatus _VI_FUNC rsfsh_setGroupDelayApertureSteps (ViSession instrumentHandle,
                                                    ViInt32 apertureSteps);
ViStatus _VI_FUNC rsfsh_getGroupDelayApertureSteps (ViSession instrumentHandle,
                                                    ViInt32* apertureSteps);
ViStatus _VI_FUNC rsfsh_setGroupDelayReferenceLevel (ViSession instrumentHandle,
                                                     ViInt32 referenceLevel);
ViStatus _VI_FUNC rsfsh_getGroupDelayReferenceLevel (ViSession instrumentHandle,
                                                     ViInt32* referenceLevel);
ViStatus _VI_FUNC rsfsh_setGroupDelayReferencePosition (ViSession instrumentHandle,
                                                        ViInt32 referencePosition);
ViStatus _VI_FUNC rsfsh_getGroupDelayReferencePosition (ViSession instrumentHandle,
                                                        ViInt32* referencePosition);
ViStatus _VI_FUNC rsfsh_setGroupDelayYScale (ViSession instrumentHandle,
                                             ViReal64 yScale);
ViStatus _VI_FUNC rsfsh_getGroupDelayYScale (ViSession instrumentHandle,
                                             ViReal64* yScale);
ViStatus _VI_FUNC rsfsh_setVectorVoltmeterReferenceState (ViSession instrumentHandle,
                                                          ViBoolean state);
ViStatus _VI_FUNC rsfsh_getVectorVoltmeterReferenceValues
             (ViSession instrumentHandle, ViReal64* magnitude, ViReal64* phase);
ViStatus _VI_FUNC rsfsh_getVectorVoltmeterMagnitudeReferenceValues
             (ViSession instrumentHandle, ViReal64* referenceValue);
ViStatus _VI_FUNC rsfsh_getVectorVoltmeterMagnitudeValues
             (ViSession instrumentHandle, ViReal64* value);
ViStatus _VI_FUNC rsfsh_getVectorVoltmeterPhaseReferenceValues
             (ViSession instrumentHandle, ViReal64* referenceValue);
ViStatus _VI_FUNC rsfsh_getVectorVoltmeterPhaseValues (ViSession instrumentHandle,
                                                       ViReal64* value);
ViStatus _VI_FUNC rsfsh_getVectorVoltmeterVoltage (ViSession instrumentHandle,
                                                   ViReal64* magnitude,
                                                   ViReal64* phase);
ViStatus _VI_FUNC rsfsh_setPowerState (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rsfsh_loadPowerStandard (ViSession instrumentHandle,
                                           ViString standard);
ViStatus _VI_FUNC rsfsh_powerStandardCheck (ViSession instrumentHandle,
                                            ViInt32* check);
ViStatus _VI_FUNC rsfsh_powerStandardResult (ViSession instrumentHandle,
                                             ViInt32 parameter, ViReal64* result);
ViStatus _VI_FUNC rsfsh_setPowerMeasurementType (ViSession instrumentHandle,
                                                 ViInt32 type);
ViStatus _VI_FUNC rsfsh_getPowerMeasurementType (ViSession instrumentHandle,
                                                 ViInt32* type);
ViStatus _VI_FUNC rsfsh_configureChannelPower (ViSession instrumentHandle,
                                               ViInt32 channelPowerStandard,
                                               ViReal64 channelPowerBandwidth,
                                               ViInt32 channelPowerUnit,
                                               ViInt32 mode);
ViStatus _VI_FUNC rsfsh_getChannelPower (ViSession instrumentHandle,
                                         ViReal64* channelPower);
ViStatus _VI_FUNC rsfsh_setChannelPowerStandard (ViSession instrumentHandle,
                                                 ViInt32 channelPowerStandard);
ViStatus _VI_FUNC rsfsh_getChannelPowerStandard (ViSession instrumentHandle,
                                                 ViInt32* channelPowerStandard);
ViStatus _VI_FUNC rsfsh_setChannelPowerCustomizedStandard
             (ViSession instrumentHandle, ViString channelPowerStandard);
ViStatus _VI_FUNC rsfsh_getChannelPowerCustomizedStandard
             (ViSession instrumentHandle, ViPString channelPowerStandard);
ViStatus _VI_FUNC rsfsh_setChannelPowerUnit (ViSession instrumentHandle,
                                             ViInt32 channelPowerUnit);
ViStatus _VI_FUNC rsfsh_getChannelPowerUnit (ViSession instrumentHandle,
                                             ViInt32* channelPowerUnit);
ViStatus _VI_FUNC rsfsh_setChannelPowerBandwidth (ViSession instrumentHandle,
                                                  ViReal64 channelPowerBandwidth);
ViStatus _VI_FUNC rsfsh_getChannelPowerBandwidth (ViSession instrumentHandle,
                                                  ViReal64* channelPowerBandwidth);
ViStatus _VI_FUNC rsfsh_setChannelPowerMode (ViSession instrumentHandle,
                                             ViInt32 mode);
ViStatus _VI_FUNC rsfsh_getChannelPowerMode (ViSession instrumentHandle,
                                             ViInt32* mode);
ViStatus _VI_FUNC rsfsh_channelPowerLevelAdjust (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_configureACPChannels (ViSession instrumentHandle,
                                              ViInt32 transmissionChannels,
                                              ViInt32 adjacentChannels);
ViStatus _VI_FUNC rsfsh_configureACPChannelBandwidth (ViSession instrumentHandle,
                                                      ViReal64 channelBandwidth,
                                                      ViInt32 adjacentChannelBandwidth,
                                                      ViInt32 alternateChannelBandwidth,
                                                      ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_configureACPSpacing (ViSession instrumentHandle,
                                             ViInt32 TXSpacing, ViInt32 TXChannel,
                                             ViInt32 adjacentSpacing,
                                             ViInt32 alternateSpacing,
                                             ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_setACPUnit (ViSession instrumentHandle,
                                    ViInt32 adjacentChannelPowerUnit);
ViStatus _VI_FUNC rsfsh_getACPUnit (ViSession instrumentHandle,
                                    ViInt32* adjacentChannelPowerUnit);
ViStatus _VI_FUNC rsfsh_setACPMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rsfsh_getACPMode (ViSession instrumentHandle, ViInt32* mode);
ViStatus _VI_FUNC rsfsh_setACPReferenceLevel (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_setACPAutomaticReferenceChannelSelection
             (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rsfsh_getACPAutomaticReferenceChannelSelection
             (ViSession instrumentHandle, ViInt32* mode);
ViStatus _VI_FUNC rsfsh_setACPReferenceTransmissionChannel
             (ViSession instrumentHandle, ViInt32 channel);
ViStatus _VI_FUNC rsfsh_getACPReferenceTransmissionChannel
             (ViSession instrumentHandle, ViInt32* channel);
ViStatus _VI_FUNC rsfsh_setACPChannelsPair (ViSession instrumentHandle,
                                            ViInt32 channels);
ViStatus _VI_FUNC rsfsh_getACPChannelsPair (ViSession instrumentHandle,
                                            ViInt32* channels);
ViStatus _VI_FUNC rsfsh_setACPChannelBandwidth (ViSession instrumentHandle,
                                                ViReal64 bandwidth);
ViStatus _VI_FUNC rsfsh_getACPChannelBandwidth (ViSession instrumentHandle,
                                                ViReal64* bandwidth);
ViStatus _VI_FUNC rsfsh_setACPAdjacentChannelBandwidth (ViSession instrumentHandle,
                                                        ViInt32 bandwidth);
ViStatus _VI_FUNC rsfsh_getACPAdjacentChannelBandwidth (ViSession instrumentHandle,
                                                        ViInt32* bandwidth);
ViStatus _VI_FUNC rsfsh_setACPAlternateChannelBandwidth (ViSession instrumentHandle,
                                                         ViInt32 bandwidth,
                                                         ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_getACPAlternateChannelBandwidth (ViSession instrumentHandle,
                                                         ViInt32* bandwidth,
                                                         ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_setACPAdjacentSpacing (ViSession instrumentHandle,
                                               ViInt32 spacing);
ViStatus _VI_FUNC rsfsh_getACPAdjacentSpacing (ViSession instrumentHandle,
                                               ViInt32* spacing);
ViStatus _VI_FUNC rsfsh_setACPAlternateSpacing (ViSession instrumentHandle,
                                                ViInt32 spacing,
                                                ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_getACPAlternateSpacing (ViSession instrumentHandle,
                                                ViInt32* spacing,
                                                ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_setACPAlternateChannelSpacing (ViSession instrumentHandle,
                                                       ViInt32 spacing,
                                                       ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_getACPAlternateChannelSpacing (ViSession instrumentHandle,
                                                       ViInt32* spacing,
                                                       ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_setACPTransmissionChannel (ViSession instrumentHandle,
                                                   ViInt32 transmissionChannel);
ViStatus _VI_FUNC rsfsh_getACPTransmissionChannel (ViSession instrumentHandle,
                                                   ViInt32* transmissionChannel);
ViStatus _VI_FUNC rsfsh_setACPLimitLineState (ViSession instrumentHandle,
                                              ViInt32 limit, ViBoolean state);
ViStatus _VI_FUNC rsfsh_getACPLimitLineState (ViSession instrumentHandle,
                                              ViInt32 limit, ViBoolean* state);
ViStatus _VI_FUNC rsfsh_configureACPLimit (ViSession instrumentHandle, ViInt32 mode,
                                           ViInt32 limit, ViReal64 adjacentLimit,
                                           ViBoolean state);
ViStatus _VI_FUNC rsfsh_configuretACPLimitAlternate (ViSession instrumentHandle,
                                                     ViInt32 mode, ViInt32 limit,
                                                     ViReal64 alterneteChannelLimit,
                                                     ViInt32 alternateChannel,
                                                     ViBoolean state);
ViStatus _VI_FUNC rsfsh_getACPLimitLineCheckResult (ViSession instrumentHandle,
                                                    ViInt32 limit,
                                                    ViChar _VI_FAR limitCheck[],
                                                    ViInt32 bufferSize);
ViStatus _VI_FUNC rsfsh_getACPAlternateLimitLineCheckResult
             (ViSession instrumentHandle, ViInt32 limit,
              ViChar _VI_FAR limitCheck[], ViInt32 bufferSize,
              ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_setACPRelativeLimit (ViSession instrumentHandle,
                                             ViInt32 limit,
                                             ViReal64 adjacentRelativeLimit);
ViStatus _VI_FUNC rsfsh_getACPRelativeLimit (ViSession instrumentHandle,
                                             ViInt32 limit,
                                             ViReal64* adjacentRelativeLimit);
ViStatus _VI_FUNC rsfsh_setACPRelaitveLimitLineState (ViSession instrumentHandle,
                                                      ViInt32 limit,
                                                      ViBoolean state);
ViStatus _VI_FUNC rsfsh_getACPRelaitveLimitLineState (ViSession instrumentHandle,
                                                      ViInt32 limit,
                                                      ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setACPAbsoluteLimit (ViSession instrumentHandle,
                                             ViInt32 limit,
                                             ViReal64 adjacentAbsoluteLimit);
ViStatus _VI_FUNC rsfsh_getACPAbsoluteLimit (ViSession instrumentHandle,
                                             ViInt32 limit,
                                             ViReal64* adjacentAbsoluteLimit);
ViStatus _VI_FUNC rsfsh_setACPAbsoluteLimitLineState (ViSession instrumentHandle,
                                                      ViInt32 limit,
                                                      ViBoolean state);
ViStatus _VI_FUNC rsfsh_getACPAbsoluteLimitLineState (ViSession instrumentHandle,
                                                      ViInt32 limit,
                                                      ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setACPRelativeLimitAlternate (ViSession instrumentHandle,
                                                      ViInt32 limit,
                                                      ViReal64 relativeLimit,
                                                      ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_getACPRelativeLimitAlternate (ViSession instrumentHandle,
                                                      ViInt32 limit,
                                                      ViReal64* relativeLimit,
                                                      ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_setACPRelativeLimitAlternateState
             (ViSession instrumentHandle, ViInt32 limit, ViBoolean state,
              ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_getACPRelativeLimitAlternateState
             (ViSession instrumentHandle, ViInt32 limit, ViBoolean* state,
              ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_setACPAbsoluteLimitAlternate (ViSession instrumentHandle,
                                                      ViInt32 limit,
                                                      ViReal64 absoluteLimit,
                                                      ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_getACPAbsoluteLimitAlternate (ViSession instrumentHandle,
                                                      ViInt32 limit,
                                                      ViReal64* absoluteLimit,
                                                      ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_setACPAbsoluteLimitAlternateState
             (ViSession instrumentHandle, ViInt32 limit, ViBoolean state,
              ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_getACPAbsoluteLimitAlternateState
             (ViSession instrumentHandle, ViInt32 limit, ViBoolean* state,
              ViInt32 alternateChannel);
ViStatus _VI_FUNC rsfsh_setHarmonicDistortionState (ViSession instrumentHandle,
                                                    ViBoolean state);
ViStatus _VI_FUNC rsfsh_getHarmonicDistortionState (ViSession instrumentHandle,
                                                    ViBoolean* state);
ViStatus _VI_FUNC rsfsh_adjustHarmonicDistortionMeasurement
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_getTotalHarmonicsDistortion (ViSession instrumentHandle,
                                                     ViReal64* totalHarmonicDistortionIn,
                                                     ViReal64* totalHarmonicDistortionInDB);
ViStatus _VI_FUNC rsfsh_setHarmonicsNumber (ViSession instrumentHandle,
                                            ViInt32 harmonicsNumber);
ViStatus _VI_FUNC rsfsh_getHarmonicsList (ViSession instrumentHandle,
                                          ViReal64 _VI_FAR harmonicsList[]);
ViStatus _VI_FUNC rsfsh_setAMModulationDepthMeasurementState
             (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rsfsh_getAMModulationDepthMeasurementState
             (ViSession instrumentHandle, ViBoolean* state);
ViStatus _VI_FUNC rsfsh_getAMModulationMeasurementResults
             (ViSession instrumentHandle, ViReal64* result);
ViStatus _VI_FUNC rsfsh_configureNetworkAnalyzerMeasurement
             (ViSession instrumentHandle, ViInt32 measurementMode,
              ViBoolean transmissionState, ViInt32 measurementFormat,
              ViInt32 measurementPort);
ViStatus _VI_FUNC rsfsh_configureNetworkAnalyzerReflectionMeasurement
             (ViSession instrumentHandle, ViBoolean reflectionState,
              ViInt32 measurementFormat);
ViStatus _VI_FUNC rsfsh_configureUserCalibrate (ViSession instrumentHandle,
                                                ViBoolean userCalkit,
                                                ViReal64 userLength,
                                                ViReal64 offsetLength);
ViStatus _VI_FUNC rsfsh_setNetworkAnalyzerMeasurementMode
             (ViSession instrumentHandle, ViInt32 measurementMode);
ViStatus _VI_FUNC rsfsh_getNetworkAnalyzerMeasurementMode
             (ViSession instrumentHandle, ViInt32* measurementMode);
ViStatus _VI_FUNC rsfsh_setNetworkAnalyzerReflectionState
             (ViSession instrumentHandle, ViBoolean reflectionState);
ViStatus _VI_FUNC rsfsh_getNetworkAnalyzerReflectionState
             (ViSession instrumentHandle, ViBoolean* reflectionState);
ViStatus _VI_FUNC rsfsh_setNetworkAnalyzerReflectionMeasurementFormat
             (ViSession instrumentHandle, ViInt32 measurementFormat);
ViStatus _VI_FUNC rsfsh_getNetworkAnalyzerReflectionMeasurementFormat
             (ViSession instrumentHandle, ViInt32* measurementFormat);
ViStatus _VI_FUNC rsfsh_setNetworkAnalyzerTransmissionState
             (ViSession instrumentHandle, ViBoolean transmissionState);
ViStatus _VI_FUNC rsfsh_getNetworkAnalyzerTransmissionState
             (ViSession instrumentHandle, ViBoolean* transmissionState);
ViStatus _VI_FUNC rsfsh_setNetworkAnalyzerTransmissionMeasurementFormat
             (ViSession instrumentHandle, ViInt32 measurementFormat);
ViStatus _VI_FUNC rsfsh_getNetworkAnalyzerTransmissionMeasurementFormat
             (ViSession instrumentHandle, ViInt32* measurementFormat);
ViStatus _VI_FUNC rsfsh_setNetworkAnalyzerMeasurementPort
             (ViSession instrumentHandle, ViInt32 measurementPort);
ViStatus _VI_FUNC rsfsh_getNetworkAnalyzerMeasurementPort
             (ViSession instrumentHandle, ViInt32* measurementPort);
ViStatus _VI_FUNC rsfsh_setUserCalkit (ViSession instrumentHandle,
                                       ViBoolean userCalkit);
ViStatus _VI_FUNC rsfsh_getUserCalkit (ViSession instrumentHandle,
                                       ViBoolean* userCalkit);
ViStatus _VI_FUNC rsfsh_setUserCalkitLength (ViSession instrumentHandle,
                                             ViReal64 userLength);
ViStatus _VI_FUNC rsfsh_getUserCalkitLength (ViSession instrumentHandle,
                                             ViReal64* userLength);
ViStatus _VI_FUNC rsfsh_userCalkitRename (ViSession instrumentHandle,
                                          ViString renameUser);
ViStatus _VI_FUNC rsfsh_setUserCalkitOffsetLength (ViSession instrumentHandle,
                                                   ViReal64 offsetLength);
ViStatus _VI_FUNC rsfsh_getUserCalkitOffsetLength (ViSession instrumentHandle,
                                                   ViReal64* offsetLength);
ViStatus _VI_FUNC rsfsh_setNetworkAnalyzerMarkersMode (ViSession instrumentHandle,
                                                       ViInt32 marker,
                                                       ViInt32 mode);
ViStatus _VI_FUNC rsfsh_getNetworkAnalyzerMarkersMode (ViSession instrumentHandle,
                                                       ViInt32 marker,
                                                       ViInt32* mode);
ViStatus _VI_FUNC rsfsh_configureDTFMeasurement (ViSession instrumentHandle,
                                                 ViInt32 DTFMeasurementMode,
                                                 ViString cableModel,
                                                 ViReal64 cableLength,
                                                 ViInt32 cableLengthUnit,
                                                 ViInt32 measurementFormat);
ViStatus _VI_FUNC rsfsh_setCableModel (ViSession instrumentHandle,
                                       ViString cableModel);
ViStatus _VI_FUNC rsfsh_getCableModel (ViSession instrumentHandle,
                                       ViChar _VI_FAR cableModel[]);
ViStatus _VI_FUNC rsfsh_setCableLength (ViSession instrumentHandle,
                                        ViReal64 cableLength);
ViStatus _VI_FUNC rsfsh_getCableLength (ViSession instrumentHandle,
                                        ViReal64* cableLength);
ViStatus _VI_FUNC rsfsh_setCableLengthUnit (ViSession instrumentHandle,
                                            ViInt32 cableLengthUnit);
ViStatus _VI_FUNC rsfsh_getCableLengthUnit (ViSession instrumentHandle,
                                            ViInt32* cableLengthUnit);
ViStatus _VI_FUNC rsfsh_selectDistancetoFaultCableModel (ViSession instrumentHandle,
                                                         ViString cableModel);
ViStatus _VI_FUNC rsfsh_setDTFMeasurementMode (ViSession instrumentHandle,
                                               ViInt32 DTFMeasurementMode);
ViStatus _VI_FUNC rsfsh_getDTFMeasurementMode (ViSession instrumentHandle,
                                               ViInt32* DTFMeasurementMode);
ViStatus _VI_FUNC rsfsh_setDistancetoFaultMeasurementFormat
             (ViSession instrumentHandle, ViInt32 measurementFormat);
ViStatus _VI_FUNC rsfsh_getDistancetoFaultMeasurementFormat
             (ViSession instrumentHandle, ViInt32* measurementFormat);
ViStatus _VI_FUNC rsfsh_calibrateDistanceToFault (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_setMarkerDistancetoFaultThreshold
             (ViSession instrumentHandle, ViReal64 threshold);
ViStatus _VI_FUNC rsfsh_getMarkerDistancetoFaultResult (ViSession instrumentHandle,
                                                        ViReal64* result);
ViStatus _VI_FUNC rsfsh_set3GPPAntennaDiversion (ViSession instrumentHandle,
                                                 ViInt32 antennaDiversityMode);
ViStatus _VI_FUNC rsfsh_get3GPPAntennaDiversion (ViSession instrumentHandle,
                                                 ViInt32* antennaDiversityMode);
ViStatus _VI_FUNC rsfsh_set3GPPPowerMode (ViSession instrumentHandle,
                                          ViInt32 powerMode);
ViStatus _VI_FUNC rsfsh_get3GPPPowerMode (ViSession instrumentHandle,
                                          ViInt32* powerMode);
ViStatus _VI_FUNC rsfsh_set3GPPScramblingCode (ViSession instrumentHandle,
                                               ViInt32 primaryScrambleCode,
                                               ViInt32 secondaryScrambleCode);
ViStatus _VI_FUNC rsfsh_get3GPPScramblingCode (ViSession instrumentHandle,
                                               ViInt32* primaryScrambleCode,
                                               ViInt32* secondaryScrambleCode);
ViStatus _VI_FUNC rsfsh_set3GPPAutoScramblingDetection (ViSession instrumentHandle,
                                                        ViInt32 detection);
ViStatus _VI_FUNC rsfsh_get3GPPMeasurement (ViSession instrumentHandle,
                                            ViInt32 measurement, ViReal64* result);
ViStatus _VI_FUNC rsfsh_get3GPPSynchronizationResult (ViSession instrumentHandle,
                                                      ViInt32* synchronizationResult);
ViStatus _VI_FUNC rsfsh_get3GPPBSResult (ViSession instrumentHandle, ViInt32 type,
                                         ViReal64* result);
ViStatus _VI_FUNC rsfsh_setPrimaryScramblingCode (ViSession instrumentHandle,
                                                  ViInt32 primaryScramblingCode);
ViStatus _VI_FUNC rsfsh_getPrimaryScramblingCode (ViSession instrumentHandle,
                                                  ViInt32* primaryScramblingCode);
ViStatus _VI_FUNC rsfsh_setSecondaryScramblingCode (ViSession instrumentHandle,
                                                    ViInt32 secondaryScramblingCode);
ViStatus _VI_FUNC rsfsh_getSecondaryScramblingCode (ViSession instrumentHandle,
                                                    ViInt32* secondaryScramblingCode);
ViStatus _VI_FUNC rsfsh_search3GPPBSScramblingCode (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_get3GPPBSCDPScramblingCodeResult (ViSession instrumentHandle,
                                                          ViInt32 arraySize,
                                                          ViInt32 _VI_FAR scrambingCode[],
                                                          ViReal64 _VI_FAR power[],
                                                          ViInt32* returnedValues);
ViStatus _VI_FUNC rsfsh_setC2KBSTPowerMode (ViSession instrumentHandle,
                                            ViInt32 powerMode);
ViStatus _VI_FUNC rsfsh_getC2KBSTPowerMode (ViSession instrumentHandle,
                                            ViInt32* powerMode);
ViStatus _VI_FUNC rsfsh_getBC2KCodeDomainAnalyzerResultSummary
             (ViSession instrumentHandle, ViInt32 resultType, ViReal64* result);
ViStatus _VI_FUNC rsfsh_setBC2KCodeDomainAnalyzerResults (ViSession instrumentHandle,
                                                          ViInt32 resultType);
ViStatus _VI_FUNC rsfsh_setSEMSweepMode (ViSession instrumentHandle,
                                         ViInt32 sweepMode);
ViStatus _VI_FUNC rsfsh_getSEMSweepMode (ViSession instrumentHandle,
                                         ViInt32* sweepMode);
ViStatus _VI_FUNC rsfsh_setSEMFrequencyCarrierStart (ViSession instrumentHandle,
                                                     ViReal64 startFrequency);
ViStatus _VI_FUNC rsfsh_getSEMFrequencyCarrierStart (ViSession instrumentHandle,
                                                     ViReal64* startFrequency);
ViStatus _VI_FUNC rsfsh_setSEMFrequencyCarrierStop (ViSession instrumentHandle,
                                                    ViReal64 stopFrequency);
ViStatus _VI_FUNC rsfsh_getSEMFrequencyCarrierStop (ViSession instrumentHandle,
                                                    ViReal64* stopFrequency);
ViStatus _VI_FUNC rsfsh_setSEMPresetStandard (ViSession instrumentHandle,
                                              ViString presetStandard);
ViStatus _VI_FUNC rsfsh_setSEMPresetSettings (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_ReadSEMPeakList (ViSession instrumentHandle,
                                         ViInt32 noOfValues,
                                         ViInt32 _VI_FAR rangeNumber[],
                                         ViReal64 _VI_FAR startFrequency[],
                                         ViReal64 _VI_FAR stopFrequency[],
                                         ViReal64 _VI_FAR resolutionBandwidth[],
                                         ViReal64 _VI_FAR frequency[],
                                         ViReal64 _VI_FAR levelAbs[],
                                         ViReal64 _VI_FAR levelRel[],
                                         ViReal64 _VI_FAR delta[],
                                         ViInt32 _VI_FAR limitCheck[],
                                         ViReal64 _VI_FAR reserved1[],
                                         ViReal64 _VI_FAR reserved2[],
                                         ViInt32* returnedValues);
ViStatus _VI_FUNC rsfsh_setEVDOPowerReference (ViSession instrumentHandle,
                                               ViInt32 powerReference);
ViStatus _VI_FUNC rsfsh_getEVDOPowerReference (ViSession instrumentHandle,
                                               ViInt32* powerReference);
ViStatus _VI_FUNC rsfsh_getEVDOCodeDomainAnalyzerGeneralResults
             (ViSession instrumentHandle, ViInt32 resultType, ViReal64* result);
ViStatus _VI_FUNC rsfsh_setEVDOBCodeDomainAnalyzerResults
             (ViSession instrumentHandle, ViInt32 resultType);
ViStatus _VI_FUNC rsfsh_configureExternalGate (ViSession instrumentHandle,
                                               ViBoolean gating, ViReal64 gateDelay,
                                               ViReal64 gateLength,
                                               ViReal64 sweepTime);
ViStatus _VI_FUNC rsfsh_setExternalGate (ViSession instrumentHandle,
                                         ViBoolean gating);
ViStatus _VI_FUNC rsfsh_getExternalGate (ViSession instrumentHandle,
                                         ViBoolean* gating);
ViStatus _VI_FUNC rsfsh_setExternalGateHoldoff (ViSession instrumentHandle,
                                                ViReal64 gateDelay);
ViStatus _VI_FUNC rsfsh_getExternalGateHoldoff (ViSession instrumentHandle,
                                                ViReal64* gateDelay);
ViStatus _VI_FUNC rsfsh_setExternalGateLength (ViSession instrumentHandle,
                                               ViReal64 gateLength);
ViStatus _VI_FUNC rsfsh_getExternalGateLength (ViSession instrumentHandle,
                                               ViReal64* gateLength);
ViStatus _VI_FUNC rsfsh_setExternalGateTime (ViSession instrumentHandle,
                                             ViReal64 sweepTime);
ViStatus _VI_FUNC rsfsh_getExternalGateTime (ViSession instrumentHandle,
                                             ViReal64* sweepTime);
ViStatus _VI_FUNC rsfsh_configureDataCapture (ViSession instrumentHandle,
                                              ViBoolean datasets, ViBoolean GPX,
                                              ViBoolean screenshots);
ViStatus _VI_FUNC rsfsh_setDataCaptureDatasets (ViSession instrumentHandle,
                                                ViBoolean datasets);
ViStatus _VI_FUNC rsfsh_getDataCaptureDatasets (ViSession instrumentHandle,
                                                ViBoolean* datasets);
ViStatus _VI_FUNC rsfsh_setDataCaptureGPX (ViSession instrumentHandle,
                                           ViBoolean GPX);
ViStatus _VI_FUNC rsfsh_getDataCaptureGPX (ViSession instrumentHandle,
                                           ViBoolean* GPX);
ViStatus _VI_FUNC rsfsh_setDataCaptureScreenshots (ViSession instrumentHandle,
                                                   ViBoolean screenshots);
ViStatus _VI_FUNC rsfsh_getDataCaptureScreenshots (ViSession instrumentHandle,
                                                   ViBoolean* screenshots);
ViStatus _VI_FUNC rsfsh_configureSavingEvents (ViSession instrumentHandle,
                                               ViBoolean state, ViInt32 storage,
                                               ViInt32 source, ViInt32 limitsMode);
ViStatus _VI_FUNC rsfsh_configureSavingEventsLimits (ViSession instrumentHandle,
                                                     ViInt32 distance,
                                                     ViInt32 time);
ViStatus _VI_FUNC rsfsh_setSavingEventsState (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rsfsh_getSavingEventsState (ViSession instrumentHandle,
                                              ViBoolean* state);
ViStatus _VI_FUNC rsfsh_setSavingEventsStorage (ViSession instrumentHandle,
                                                ViInt32 storage);
ViStatus _VI_FUNC rsfsh_getSavingEventsStorage (ViSession instrumentHandle,
                                                ViInt32* storage);
ViStatus _VI_FUNC rsfsh_setSavingEventsSource (ViSession instrumentHandle,
                                               ViInt32 source);
ViStatus _VI_FUNC rsfsh_getSavingEventsSource (ViSession instrumentHandle,
                                               ViInt32* source);
ViStatus _VI_FUNC rsfsh_setSavingEventsDistance (ViSession instrumentHandle,
                                                 ViInt32 distance);
ViStatus _VI_FUNC rsfsh_getSavingEventsDistance (ViSession instrumentHandle,
                                                 ViInt32* distance);
ViStatus _VI_FUNC rsfsh_setSavingEventsLimitsMode (ViSession instrumentHandle,
                                                   ViInt32 limitsMode);
ViStatus _VI_FUNC rsfsh_getSavingEventsLimitsMode (ViSession instrumentHandle,
                                                   ViInt32* limitsMode);
ViStatus _VI_FUNC rsfsh_setSavingEventsTime (ViSession instrumentHandle,
                                             ViInt32 time);
ViStatus _VI_FUNC rsfsh_getSavingEventsTime (ViSession instrumentHandle,
                                             ViInt32* time);
ViStatus _VI_FUNC rsfsh_fileDirectoriesCatalog (ViSession instrumentHandle,
                                                ViString directoryPath,
                                                ViInt32 arraySize,
                                                ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rsfsh_FileDirectory (ViSession instrumentHandle,
                                       ViString directory, ViInt32 bufferSize,
                                       ViChar _VI_FAR output[]);
ViStatus _VI_FUNC rsfsh_FileManagerOperations (ViSession instrumentHandle,
                                               ViInt32 operation, ViString source,
                                               ViString destination);
ViStatus _VI_FUNC rsfsh_fileCreate (ViSession instrumentHandle, ViString fileName);
ViStatus _VI_FUNC rsfsh_setFileDate (ViSession instrumentHandle, ViString fileName,
                                     ViInt32 year, ViInt32 month, ViInt32 day);
ViStatus _VI_FUNC rsfsh_getFileDate (ViSession instrumentHandle, ViString fileName,
                                     ViChar _VI_FAR date[]);
ViStatus _VI_FUNC rsfsh_setFileTime (ViSession instrumentHandle, ViString fileName,
                                     ViInt32 hours, ViInt32 minutes,
                                     ViInt32 seconds);
ViStatus _VI_FUNC rsfsh_getFileTime (ViSession instrumentHandle, ViString fileName,
                                     ViChar _VI_FAR time[]);
ViStatus _VI_FUNC rsfsh_DataSetFileOperations (ViSession instrumentHandle,
                                               ViInt32 operation, ViString path);
ViStatus _VI_FUNC rsfsh_saveDataset (ViSession instrumentHandle,
                                     ViString datasetName);
ViStatus _VI_FUNC rsfsh_recallDataset (ViSession instrumentHandle,
                                       ViString datasetName);
ViStatus _VI_FUNC rsfsh_screenshotAndCopyTrace (ViSession instrumentHandle,
                                                ViString pathAndFileName);
ViStatus _VI_FUNC rsfsh_configureDisplay (ViSession instrumentHandle,
                                          ViReal64 brightness, ViInt32 colorScheme,
                                          ViInt32 dateFormat);
ViStatus _VI_FUNC rsfsh_displayColorSchemeDefault (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_configureEthernet (ViSession instrumentHandle,
                                           ViBoolean DHCP, ViString IPAddress,
                                           ViString subnetMask, ViInt32 port);
ViStatus _VI_FUNC rsfsh_configureVolume (ViSession instrumentHandle,
                                         ViReal64 audioVolume,
                                         ViReal64 beeperVolume, ViReal64 keyVolume);
ViStatus _VI_FUNC rsfsh_configureUnit (ViSession instrumentHandle,
                                       ViInt32 unitLength, ViInt32 powerUnit);
ViStatus _VI_FUNC rsfsh_setDisplayBrightness (ViSession instrumentHandle,
                                              ViReal64 brightness);
ViStatus _VI_FUNC rsfsh_getDisplayBrightness (ViSession instrumentHandle,
                                              ViReal64* brightness);
ViStatus _VI_FUNC rsfsh_setDisplayColorScheme (ViSession instrumentHandle,
                                               ViInt32 colorScheme);
ViStatus _VI_FUNC rsfsh_getDisplayColorScheme (ViSession instrumentHandle,
                                               ViInt32* colorScheme);
ViStatus _VI_FUNC rsfsh_setDisplayDateFormat (ViSession instrumentHandle,
                                              ViInt32 dateFormat);
ViStatus _VI_FUNC rsfsh_getDisplayDateFormat (ViSession instrumentHandle,
                                              ViInt32* dateFormat);
ViStatus _VI_FUNC rsfsh_setAudioVolume (ViSession instrumentHandle,
                                        ViReal64 audioVolume);
ViStatus _VI_FUNC rsfsh_getAudioVolume (ViSession instrumentHandle,
                                        ViReal64* audioVolume);
ViStatus _VI_FUNC rsfsh_setBeeperVolume (ViSession instrumentHandle,
                                         ViReal64 beeperVolume);
ViStatus _VI_FUNC rsfsh_getBeeperVolume (ViSession instrumentHandle,
                                         ViReal64* beeperVolume);
ViStatus _VI_FUNC rsfsh_setKeyVolume (ViSession instrumentHandle,
                                      ViReal64 keyVolume);
ViStatus _VI_FUNC rsfsh_getKeyVolume (ViSession instrumentHandle,
                                      ViReal64* keyVolume);
ViStatus _VI_FUNC rsfsh_setBNCMode (ViSession instrumentHandle, ViInt32 BNC,
                                    ViInt32 BNCMode);
ViStatus _VI_FUNC rsfsh_getBNCMode (ViSession instrumentHandle, ViInt32 BNC,
                                    ViInt32* BNCMode);
ViStatus _VI_FUNC rsfsh_getAutoOffTime (ViSession instrumentHandle,
                                        ViInt32* autoOffTime);
ViStatus _VI_FUNC rsfsh_getPowerSource (ViSession instrumentHandle,
                                        ViChar _VI_FAR powerSource[]);
ViStatus _VI_FUNC rsfsh_getRemainingBatteryPower (ViSession instrumentHandle,
                                                  ViInt32* remainingBatteryPower);
ViStatus _VI_FUNC rsfsh_setLanguage (ViSession instrumentHandle, ViString language);
ViStatus _VI_FUNC rsfsh_getLanguage (ViSession instrumentHandle,
                                     ViChar _VI_FAR language[]);
ViStatus _VI_FUNC rsfsh_getLanguageCatalog (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rsfsh_setReferenceOscillatorSource (ViSession instrumentHandle,
                                                      ViInt32 source);
ViStatus _VI_FUNC rsfsh_getReferenceOscillatorSource (ViSession instrumentHandle,
                                                      ViInt32* source);
ViStatus _VI_FUNC rsfsh_getSystemMemoryInfo (ViSession instrumentHandle,
                                             ViInt32* totalMemory,
                                             ViInt32* usedMemory);
ViStatus _VI_FUNC rsfsh_getStoreMemoryInfo (ViSession instrumentHandle,
                                            ViInt32* totalMemory,
                                            ViInt32* usedMemory,
                                            ViInt32* freeMemory);
ViStatus _VI_FUNC rsfsh_SystemReboot (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_getEthernetMACAddress (ViSession instrumentHandle,
                                               ViChar _VI_FAR MACAddress[]);
ViStatus _VI_FUNC rsfsh_setEthernetSubmask (ViSession instrumentHandle,
                                            ViString subnetMask);
ViStatus _VI_FUNC rsfsh_getEthernetSubmask (ViSession instrumentHandle,
                                            ViChar _VI_FAR subnetMask[]);
ViStatus _VI_FUNC rsfsh_setEthernetIPAddress (ViSession instrumentHandle,
                                              ViString IPAddress);
ViStatus _VI_FUNC rsfsh_getEthernetIPAddress (ViSession instrumentHandle,
                                              ViChar _VI_FAR IPAddress[]);
ViStatus _VI_FUNC rsfsh_setEthernetDHCPMode (ViSession instrumentHandle,
                                             ViBoolean DHCPMode);
ViStatus _VI_FUNC rsfsh_getEthernetDHCPMode (ViSession instrumentHandle,
                                             ViBoolean* DHCPMode);
ViStatus _VI_FUNC rsfsh_setEthernetPort (ViSession instrumentHandle, ViInt32 port);
ViStatus _VI_FUNC rsfsh_getEthernetPort (ViSession instrumentHandle, ViInt32* port);
ViStatus _VI_FUNC rsfsh_setRemoteDesktopPort (ViSession instrumentHandle,
                                              ViInt32 portNumber);
ViStatus _VI_FUNC rsfsh_getRemoteDesktopPort (ViSession instrumentHandle,
                                              ViInt32* portNumber);
ViStatus _VI_FUNC rsfsh_setGPSState (ViSession instrumentHandle, ViBoolean GPS);
ViStatus _VI_FUNC rsfsh_getGPSState (ViSession instrumentHandle, ViBoolean* GPS);
ViStatus _VI_FUNC rsfsh_getGPSConnected (ViSession instrumentHandle,
                                         ViBoolean* GPSConnected);
ViStatus _VI_FUNC rsfsh_getGPSFrequencyCorrection (ViSession instrumentHandle,
                                                   ViReal64* correctionFactor);
ViStatus _VI_FUNC rsfsh_getGPSSignalQuality (ViSession instrumentHandle,
                                             ViInt32* signalQuality);
ViStatus _VI_FUNC rsfsh_getGPSSatellites (ViSession instrumentHandle,
                                          ViInt32* satellites);
ViStatus _VI_FUNC rsfsh_getGPSLatitude (ViSession instrumentHandle,
                                        ViInt32 bufferSize,
                                        ViChar _VI_FAR latitude[]);
ViStatus _VI_FUNC rsfsh_getGPSLongitude (ViSession instrumentHandle,
                                         ViInt32 bufferSize,
                                         ViChar _VI_FAR longitude[]);
ViStatus _VI_FUNC rsfsh_getGPSAltitude (ViSession instrumentHandle,
                                        ViInt32 bufferSize,
                                        ViChar _VI_FAR altitude[]);
ViStatus _VI_FUNC rsfsh_getGPSPositionInformation (ViSession instrumentHandle,
                                                   ViBoolean* positionInformation);
ViStatus _VI_FUNC rsfsh_setUnitLength (ViSession instrumentHandle,
                                       ViInt32 unitLength);
ViStatus _VI_FUNC rsfsh_getUnitLength (ViSession instrumentHandle,
                                       ViInt32* unitLength);
ViStatus _VI_FUNC rsfsh_setUnitPower (ViSession instrumentHandle,
                                      ViInt32 powerUnit);
ViStatus _VI_FUNC rsfsh_getUnitPower (ViSession instrumentHandle,
                                      ViInt32* powerUnit);
ViStatus _VI_FUNC rsfsh_getCalibrationMode (ViSession instrumentHandle,
                                            ViInt32* calibrationMode);
ViStatus _VI_FUNC rsfsh_getCalibrationStatus (ViSession instrumentHandle,
                                              ViChar _VI_FAR calibrationStatus[]);
ViStatus _VI_FUNC rsfsh_calibrationStart (ViSession instrumentHandle,
                                          ViInt32 method,
                                          ViChar _VI_FAR calibration[]);
ViStatus _VI_FUNC rsfsh_calibrationContinue (ViSession instrumentHandle,
                                             ViChar _VI_FAR calibrationContinue[]);
ViStatus _VI_FUNC rsfsh_calibrationAbort (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_setStatusRegister (ViSession instrumentHandle,
                                           ViInt32 registerOperation,
                                           ViInt32 questionableRegister,
                                           ViInt32 enable, ViInt32 PTransition,
                                           ViInt32 NTransition);
ViStatus _VI_FUNC rsfsh_getStatusRegister (ViSession instrumentHandle,
                                           ViInt32 statusRegistersQuery,
                                           ViInt32* registerValue);
ViStatus _VI_FUNC rsfsh_StatusQueueNext (ViSession instrumentHandle,
                                         ViReal64* errorNumber);
ViStatus _VI_FUNC rsfsh_writeInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rsfsh_readInstrData (ViSession instrumentHandle,
                                       ViInt32 numberBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViInt32* numBytesRead);
ViStatus _VI_FUNC rsfsh_presetSettings (ViSession instrumentHandle,
                                        ViInt32 presetSettings);
ViStatus _VI_FUNC rsfsh_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_temperature (ViSession instrumentHandle,
                                     ViReal64* temperature);
ViStatus _VI_FUNC rsfsh_self_test (ViSession instrumentHandle,
                                   ViInt16* selfTestResult,
                                   ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsfsh_error_query (ViSession instrumentHandle, ViInt32* errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsfsh_error_message (ViSession instrumentHandle,
                                       ViStatus statusCode,
                                       ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rsfsh_getAllErrors (ViSession instrumentHandle, ViInt32 length,
                                      ViChar _VI_FAR errors[]);
ViStatus _VI_FUNC rsfsh_revision_query (ViSession instrumentHandle,
                                        ViChar _VI_FAR instrumentDriverRevision[],
                                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsfsh_systemVersion (ViSession instrumentHandle, ViInt32 length,
                                       ViChar _VI_FAR systemVersion[]);
ViStatus _VI_FUNC rsfsh_setSystemTimeShift (ViSession instrumentHandle,
                                            ViInt32 hours, ViInt32 minutes);
ViStatus _VI_FUNC rsfsh_getSystemTimeShift (ViSession instrumentHandle,
                                            ViInt32 length,
                                            ViChar _VI_FAR timeShift[]);
ViStatus _VI_FUNC rsfsh_presetFactory (ViSession instrumentHandle);
ViStatus _VI_FUNC rsfsh_ReadToFileFromInstrument (ViSession instrumentHandle,
                                                  ViString fileName,
                                                  ViInt32 binaryBlockLength,
                                                  ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rsfsh_WriteFromFileToInstrument (ViSession instrumentHandle,
                                                   ViString fileName,
                                                   ViInt32 binaryBlockLength,
                                                   ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rsfsh_close (ViSession instrumentHandle);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
