#include <visa.h>

/*= Useful Macros ===========================================================*/

/* - Basic Macros ---------------------------------------------------------- */

/* Error checking macro */
#define CHECKERR(fCal) if (rsfsh_status = (fCal), rsfsh_status < VI_SUCCESS) \
    return rsfsh_status

/* Error checking macro with jump to the ERROR: label */
#define GOCHECKERR(fCal) if (rsfsh_status = (fCal), rsfsh_status < VI_SUCCESS) \
                            goto ERROR_LABEL
/**#define GOCHECKERR(fCal) if (rsfsh_status = (fCal), rsfsh_status < VI_SUCCESS) \
                            goto ERROR_LABEL; else
*/
/* Parameter checking macro */
#define CHECKPARAM(fCal,param) if (fCal != VI_SUCCESS) return VI_ERROR_PARAMETER##param

/* Checking path parameter */
#define CHECKPATH if (rsfsh_invalidViInt32Range (path, 1, 2) != 0) return VI_ERROR_PARAMETER2;

/* Initialize default function parameters */
#define INIT\
    ViStatus            rsfsh_status = VI_SUCCESS; \
    rsfsh_instrRange    instrPtr = NULL; \
    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));\
    if (instrPtr == NULL)\
        return VI_ERROR_PARAMETER1

/* Close function and return */
#define RETURN\
    return rsfsh_status;

/* - Additional Macros ----------------------------------------------------- */

#define CHECKOPT(option) if (instrPtr->optionChecking == VI_TRUE)\
                         {\
                            if (instrPtr->instrOptions.option == 0)\
                                return rsfsh_ERROR_INSTRUMENT_OPTION;\
                         }

#define CHECKOPTCONT(option) if (instrPtr->optionChecking == VI_TRUE)\
                         {\
                            if (instrPtr->instrOptions.option == 0)\
                                rsfsh_status = rsfsh_ERROR_INSTRUMENT_OPTION;\
                         }
/* Remap parameter error code */
#define REMAP(par_in, par_out) if (rsfsh_status == VI_ERROR_PARAMETER##par_in)\
                                    rsfsh_status = VI_ERROR_PARAMETER##par_out;\
                                if (rsfsh_status < VI_SUCCESS)\
                                    return rsfsh_status

#define REMAPINSTR(par_in, par_out) if (rsfsh_status == VI_ERROR_PARAMETER##par_in)\
                                    rsfsh_status = VI_ERROR_INSTR_PARAMETER##par_out;\
                                if (rsfsh_status < VI_SUCCESS)\
                                    return rsfsh_status

/* Check NULL pointer */
#define CHECKNULL(pointer, param) if (pointer == NULL) return VI_ERROR_PARAMETER##param


/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE STRUCTURE  ============================*/
/*****************************************************************************/
/* rsfsh_stringValPair is used in the rsfsh_error_message function           */
/* rsfsh_statusDataRanges is used to track session dependent status & ranges */
/*===========================================================================*/
typedef struct  rsfsh_stringValPair
{
   ViStatus stringVal;
   ViString stringName;
}  rsfsh_tStringValPair;

typedef struct rsfsh_instrOptions
{
    int B20:1;
    int B22:1;
    int B29:1;
    int B80:1;
    int B81:1;
    int B103:1;
    int B106:1;
    int K23:1;
    int K24:1;
    int K25:1;
    int K83:1;
    int K27:1;
    int K22:1;
    int K20:1;
    int K4:1;
} rsfsh_tinstrOptions;

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE STRUCTURE  ============================*/
/*****************************************************************************/
/* rsfsh_stringValPair is used in the rsfsh_error_message function           */
/* rsfsh_statusDataRanges is used to track session dependent status & ranges */
/*===========================================================================*/
struct rsfsh_statusDataRanges
{
    ViChar instrDriverRevision[256];
    ViInt32 multiMarker;
    ViInt32 deltaMarker;
    ViBoolean fsh3;
    ViBoolean           errorChecking;
};

typedef struct rsfsh_statusDataRanges *rsfsh_instrRange;

ViBoolean rsfsh_invalidViBooleanRange (ViBoolean val);
ViBoolean rsfsh_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max);
ViBoolean rsfsh_invalidViReal64Range (ViReal64 val, ViReal64 min,
                                       ViReal64 max);
ViStatus rsfsh_checkStatus (ViSession instrSession);
ViStatus rsfsh_waitOPC (ViSession instrSession, ViPString command,
                        ViPString instrResp, ViInt32 timeout);
ViStatus rsfsh_sendCmd (ViSession instrSession, ViString cmd);
ViStatus rsfsh_setViInt32 (ViSession instrSession,
                           ViString cmd,
                           ViInt32 value,
                           ViInt32 min,
                           ViInt32 max,
                           ViStatus parameterErrorCode);
ViStatus rsfsh_getViInt32 (ViSession instrSession,
                           ViString cmd,
                           ViInt32 *value,
                           ViStatus parameterErrorCode);
ViStatus rsfsh_setViBoolean (ViSession instrSession,
                           ViString cmd,
                           ViBoolean value,
                           ViStatus parameterErrorCode);
ViStatus rsfsh_getViBoolean (ViSession instrSession,
                           ViString cmd,
                           ViBoolean *value,
                           ViStatus parameterErrorCode);
ViStatus rsfsh_setViBooleanPath (ViSession instrSession,
                           ViString cmd,
                           ViInt32 path,
                           ViBoolean value,
                           ViStatus parameterErrorCode);
ViStatus rsfsh_getViBooleanPath (ViSession instrSession,
                           ViString cmd,
                           ViInt32 path,
                           ViBoolean *value,
                           ViStatus parameterErrorCode);
ViStatus rsfsh_setViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 value,
                            ViReal64 min,
                            ViReal64 max,
                            ViStatus parameterErrorCode);
ViStatus rsfsh_setViReal64Path (ViSession instrSession,
                            ViString cmd,
                            ViInt32  path,
                            ViReal64 value,
                            ViReal64 min,
                            ViReal64 max,
                            ViStatus parameterErrorCode);
ViStatus rsfsh_getViReal64Path (ViSession instrSession,
                            ViString cmd,
                            ViInt32 path,
                            ViReal64 *value,
                            ViStatus parameterErrorCode);
ViStatus rsfsh_getViReal64 (ViSession instrSession,
                            ViString cmd,
                            ViReal64 *value,
                            ViStatus parameterErrorCode);
ViStatus rsfsh_setViReal64Units (ViSession instrSession,
                                 ViString cmd,
                                 ViReal64 value,
                                 ViString units,
                                 ViReal64 min,
                                 ViReal64 max,
                                 ViStatus parameterErrorCode);
ViStatus rsfsh_setViString (ViSession instrSession,
                            ViString cmd,
                            ViString value,
                            ViStatus parameterErrorValue);
ViStatus rsfsh_getViString (ViSession instrSession,
                            ViString cmd,
                            ViString value,
                            ViUInt32 buffer_size,
                            ViStatus parameterErrorCode);
ViStatus rsfsh_setViStringQuoted (ViSession instrSession,
                            ViString cmd,
                            ViString quotes,
                            ViString value,
                            ViStatus parameterErrorValue);
ViStatus rsfsh_getViStringQuoted (ViSession instrSession,
                                  ViString cmd,
                                  ViString quotes,
                                  ViInt32  arraySize,
                                  ViChar   value[],
                                  ViStatus parameterErrorValue);
ViStatus rsfsh_setViStringPath (ViSession instrSession,
                            ViString cmd,
                            ViInt32 path,
                            ViString value,
                            ViStatus parameterErrorValue);
ViStatus rsfsh_setEnum (ViSession instrSession,
                        ViString cmd,
                        ViInt32 value,
                        ViString list[],
                        ViStatus parameterErrorCode);
ViStatus rsfsh_getEnum (ViSession instrSession,
                        ViString cmd,
                        ViInt32 *value,
                        ViString list[],
                        ViStatus parameterErrorCode);
ViStatus rsfsh_setEnumPath (ViSession instrSession,
                        ViString cmd,
                        ViInt32 path,
                        ViInt32 value,
                        ViString list[],
                        ViStatus parameterErrorCode);
ViStatus rsfsh_getEnumPath (ViSession instrSession,
                        ViString cmd,
                        ViInt32 path,
                        ViInt32 *value,
                        ViString list[],
                        ViStatus parameterErrorCode);
ViStatus rsfsh_setViUInt32 (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 value,
                           ViUInt32 min,
                           ViUInt32 max,
                           ViStatus parameterErrorCode);
ViStatus rsfsh_getViUInt32 (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 *value,
                           ViStatus parameterErrorCode);
ViStatus rsfsh_checkIndexInList (ViInt32 index,
                                 ViString list[],
                                 ViStatus statusIfError);
ViStatus rsfsh_getIndexFromString (ViString string,
                                   ViString *list,
                                   ViInt32 *index);
ViStatus rsfsh_getCatalog (ViSession instrSession,
                           ViString cmd,
                           ViInt32 arraySize,
                           ViChar* array,
                           ViInt32 parameterErrorCode);
ViStatus rsfsh_getViReal64Array (ViSession instrSession,
                            ViString cmd,
                            ViReal64 *value,
                            ViInt32  count,
                            ViStatus parameterErrorCode);
ViStatus rsfsh_readDataUnknownLength(ViSession instrSession,
                                     /*@null@*/ViChar **outBuffer,
                                     ViUInt32 *count);
ViStatus rsfsh_readDataToFile (ViSession instrSession, ViString cmd,
                           ViString destination);
void rsfsh_SWAP_32(unsigned char *data, long points);
ViStatus rsfsh_dataReadTrace (ViSession instrSession,
                              ViString trace, 
                              ViInt32 arrayLength, 
                              /*@out@*/ViReal64 _VI_FAR traceData[],
                              ViPInt32 noofPoints);
ViStatus rsfsh_delay (ViSession instrSession, ViReal64 seconds);                                 
ViStatus rsfsh_dataReadTraceOnly (ViSession instrSession,
                                 ViInt32 arrayLength, 
                                 /*@out@*/ViReal64 _VI_FAR traceData[],
                                 ViPInt32 noofPoints);
